@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver;
 
 use Doctrine\DBAL\Connection;
@@ -7,7 +9,6 @@ use Doctrine\DBAL\Driver\AbstractSQLServerDriver\Exception\PortWithoutHost;
 use Doctrine\DBAL\Driver\API\ExceptionConverter as ExceptionConverterInterface;
 use Doctrine\DBAL\Driver\API\SQLSrv\ExceptionConverter;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Platforms\SQLServer2012Platform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\SQLServerSchemaManager;
@@ -17,7 +18,7 @@ abstract class AbstractSQLServerDriverTestCase extends AbstractDriverTestCase
 {
     protected function createPlatform(): AbstractPlatform
     {
-        return new SQLServer2012Platform();
+        return new SQLServerPlatform();
     }
 
     protected function createSchemaManager(Connection $connection): AbstractSchemaManager
@@ -38,4 +39,9 @@ abstract class AbstractSQLServerDriverTestCase extends AbstractDriverTestCase
         $this->expectException(PortWithoutHost::class);
         $this->driver->connect(['port' => 1433]);
     }
+
+    public function testThrowsExceptionOnCreatingDatabasePlatformsForInvalidVersion(): void
+    {
+        self::markTestSkipped('SQL Server drivers do not use server version to instantiate platform');
+    }
 }
