@@ -1,26 +1,28 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver;
 
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Driver\API\ExceptionConverter;
 use Doctrine\DBAL\Driver\API\SQLite;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\SqliteSchemaManager;
+use Doctrine\DBAL\Schema\SQLiteSchemaManager;
 
-/** @extends AbstractDriverTestCase<SqlitePlatform> */
+/** @extends AbstractDriverTestCase<SQLitePlatform> */
 abstract class AbstractSQLiteDriverTestCase extends AbstractDriverTestCase
 {
     protected function createPlatform(): AbstractPlatform
     {
-        return new SqlitePlatform();
+        return new SQLitePlatform();
     }
 
     protected function createSchemaManager(Connection $connection): AbstractSchemaManager
     {
-        return new SqliteSchemaManager(
+        return new SQLiteSchemaManager(
             $connection,
             $this->createPlatform(),
         );
@@ -30,4 +32,9 @@ abstract class AbstractSQLiteDriverTestCase extends AbstractDriverTestCase
     {
         return new SQLite\ExceptionConverter();
     }
+
+    public function testThrowsExceptionOnCreatingDatabasePlatformsForInvalidVersion(): void
+    {
+        self::markTestSkipped('SQLite drivers do not use server version to instantiate platform');
+    }
 }
