@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\ParameterType;
@@ -61,9 +63,11 @@ class BlobTest extends FunctionalTestCase
 
         self::assertEquals(1, $ret);
 
-        [$clobValue, $blobValue] = $this->fetchRow();
-        self::assertNull($clobValue);
-        self::assertNull($blobValue);
+        $row = $this->fetchRow();
+        self::assertCount(2, $row);
+
+        self::assertNull($row[0]);
+        self::assertNull($row[1]);
     }
 
     public function testInsertProcessesStream(): void
@@ -160,12 +164,10 @@ class BlobTest extends FunctionalTestCase
             "INSERT INTO blob_table(id, clobcolumn, blobcolumn) VALUES (1, 'ignored', ?)",
         );
 
-        $stmt->bindParam(1, $stream, ParameterType::LARGE_OBJECT);
-
-        // Bind param does late binding (bind by reference), so create the stream only now:
         $stream = fopen('data://text/plain,test', 'r');
+        $stmt->bindValue(1, $stream, ParameterType::LARGE_OBJECT);
 
-        $stmt->execute();
+        $stmt->executeStatement();
 
         $this->assertBlobContains('test');
     }
