@@ -1,33 +1,35 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use DateTime;
 use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\ParameterType;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Platforms\TrimMode;
 use Doctrine\DBAL\Schema\Table;
+use Doctrine\DBAL\Statement;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
-use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Types;
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function array_change_key_case;
 use function date;
+use function sprintf;
 use function strtotime;
 
 use const CASE_LOWER;
 
 class DataAccessTest extends FunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $table = new Table('fetch_table');
         $table->addColumn('test_int', Types::INTEGER);
-        $table->addColumn('test_string', Types::STRING);
+        $table->addColumn('test_string', Types::STRING, ['length' => 32]);
         $table->addColumn('test_datetime', Types::DATETIME_MUTABLE, ['notnull' => false]);
         $table->setPrimaryKey(['test_int']);
 
@@ -48,25 +50,7 @@ class DataAccessTest extends FunctionalTestCase
         $stmt->bindValue(1, 1);
         $stmt->bindValue(2, 'foo');
 
-        $row = $stmt->execute()->fetchAssociative();
-
-        self::assertIsArray($row);
-        $row = array_change_key_case($row, CASE_LOWER);
-        self::assertEquals(['test_int' => 1, 'test_string' => 'foo'], $row);
-    }
-
-    public function testPrepareWithBindParam(): void
-    {
-        $paramInt = 1;
-        $paramStr = 'foo';
-
-        $sql  = 'SELECT test_int, test_string FROM fetch_table WHERE test_int = ? AND test_string = ?';
-        $stmt = $this->connection->prepare($sql);
-
-        $stmt->bindParam(1, $paramInt);
-        $stmt->bindParam(2, $paramStr);
-
-        $row = $stmt->execute()->fetchAssociative();
+        $row = $stmt->executeQuery()->fetchAssociative();
 
         self::assertIsArray($row);
         $row = array_change_key_case($row, CASE_LOWER);
@@ -81,10 +65,10 @@ class DataAccessTest extends FunctionalTestCase
         $sql  = 'SELECT test_int, test_string FROM fetch_table WHERE test_int = ? AND test_string = ?';
         $stmt = $this->connection->prepare($sql);
 
-        $stmt->bindParam(1, $paramInt);
-        $stmt->bindParam(2, $paramStr);
+        $stmt->bindValue(1, $paramInt);
+        $stmt->bindValue(2, $paramStr);
 
-        $rows    = $stmt->execute()->fetchAllAssociative();
+        $rows    = $stmt->executeQuery()->fetchAllAssociative();
         $rows[0] = array_change_key_case($rows[0], CASE_LOWER);
         self::assertEquals(['test_int' => 1, 'test_string' => 'foo'], $rows[0]);
     }
@@ -97,28 +81,13 @@ class DataAccessTest extends FunctionalTestCase
         $sql  = 'SELECT test_int FROM fetch_table WHERE test_int = ? AND test_string = ?';
         $stmt = $this->connection->prepare($sql);
 
-        $stmt->bindParam(1, $paramInt);
-        $stmt->bindParam(2, $paramStr);
+        $stmt->bindValue(1, $paramInt);
+        $stmt->bindValue(2, $paramStr);
 
-        $column = $stmt->execute()->fetchOne();
+        $column = $stmt->executeQuery()->fetchOne();
         self::assertEquals(1, $column);
     }
 
-    public function testPrepareWithExecuteParams(): void
-    {
-        $paramInt = 1;
-        $paramStr = 'foo';
-
-        $sql    = 'SELECT test_int, test_string FROM fetch_table WHERE test_int = ? AND test_string = ?';
-        $stmt   = $this->connection->prepare($sql);
-        $result = $stmt->execute([$paramInt, $paramStr]);
-
-        $row = $result->fetchAssociative();
-        self::assertNotFalse($row);
-        $row = array_change_key_case($row, CASE_LOWER);
-        self::assertEquals(['test_int' => 1, 'test_string' => 'foo'], $row);
-    }
-
     public function testFetchAllAssociative(): void
     {
         $sql  = 'SELECT test_int, test_string FROM fetch_table WHERE test_int = ? AND test_string = ?';
@@ -287,8 +256,9 @@ class DataAccessTest extends FunctionalTestCase
     {
         $sql  = 'SELECT count(*) AS c FROM fetch_table WHERE test_datetime = ?';
         $stmt = $this->connection->prepare($sql);
+
         $stmt->bindValue(1, new DateTime('2010-01-01 10:10:10'), Types::DATETIME_MUTABLE);
-        $result = $stmt->execute();
+        $result = $stmt->executeQuery();
 
         self::assertEquals(1, $result->fetchOne());
     }
@@ -324,15 +294,11 @@ class DataAccessTest extends FunctionalTestCase
         self::assertEquals([[100], [101], [102], [103], [104]], $data);
     }
 
-    /**
-     * @param string|false $char
-     *
-     * @dataProvider getTrimExpressionData
-     */
-    public function testTrimExpression(string $value, int $position, $char, string $expectedResult): void
+    #[DataProvider('getTrimExpressionData')]
+    public function testTrimExpression(string $value, TrimMode $mode, ?string $char, string $expectedResult): void
     {
         $sql = 'SELECT ' .
-            $this->connection->getDatabasePlatform()->getTrimExpression($value, $position, $char) . ' AS trimmed ' .
+            $this->connection->getDatabasePlatform()->getTrimExpression($value, $mode, $char) . ' AS trimmed ' .
             'FROM fetch_table';
 
         $row = $this->connection->fetchAssociative($sql);
@@ -346,10 +312,10 @@ class DataAccessTest extends FunctionalTestCase
     public static function getTrimExpressionData(): iterable
     {
         return [
-            ['test_string', TrimMode::UNSPECIFIED, false, 'foo'],
-            ['test_string', TrimMode::LEADING, false, 'foo'],
-            ['test_string', TrimMode::TRAILING, false, 'foo'],
-            ['test_string', TrimMode::BOTH, false, 'foo'],
+            ['test_string', TrimMode::UNSPECIFIED, null, 'foo'],
+            ['test_string', TrimMode::LEADING, null, 'foo'],
+            ['test_string', TrimMode::TRAILING, null, 'foo'],
+            ['test_string', TrimMode::BOTH, null, 'foo'],
             ['test_string', TrimMode::UNSPECIFIED, "'f'", 'oo'],
             ['test_string', TrimMode::UNSPECIFIED, "'o'", 'f'],
             ['test_string', TrimMode::UNSPECIFIED, "'.'", 'foo'],
@@ -362,10 +328,10 @@ class DataAccessTest extends FunctionalTestCase
             ['test_string', TrimMode::BOTH, "'f'", 'oo'],
             ['test_string', TrimMode::BOTH, "'o'", 'f'],
             ['test_string', TrimMode::BOTH, "'.'", 'foo'],
-            ["' foo '", TrimMode::UNSPECIFIED, false, 'foo'],
-            ["' foo '", TrimMode::LEADING, false, 'foo '],
-            ["' foo '", TrimMode::TRAILING, false, ' foo'],
-            ["' foo '", TrimMode::BOTH, false, 'foo'],
+            ["' foo '", TrimMode::UNSPECIFIED, null, 'foo'],
+            ["' foo '", TrimMode::LEADING, null, 'foo '],
+            ["' foo '", TrimMode::TRAILING, null, ' foo'],
+            ["' foo '", TrimMode::BOTH, null, 'foo'],
             ["' foo '", TrimMode::UNSPECIFIED, "'f'", ' foo '],
             ["' foo '", TrimMode::UNSPECIFIED, "'o'", ' foo '],
             ["' foo '", TrimMode::UNSPECIFIED, "'.'", ' foo '],
@@ -385,55 +351,291 @@ class DataAccessTest extends FunctionalTestCase
         ];
     }
 
-    public function testDateArithmetics(): void
+    #[DataProvider('modeProvider')]
+    public function testDateAddSeconds(callable $buildQuery, callable $bindParams): void
     {
-        $p    = $this->connection->getDatabasePlatform();
-        $sql  = 'SELECT ';
-        $sql .= $p->getDateAddSecondsExpression('test_datetime', 1) . ' AS add_seconds, ';
-        $sql .= $p->getDateSubSecondsExpression('test_datetime', 1) . ' AS sub_seconds, ';
-        $sql .= $p->getDateAddMinutesExpression('test_datetime', 5) . ' AS add_minutes, ';
-        $sql .= $p->getDateSubMinutesExpression('test_datetime', 5) . ' AS sub_minutes, ';
-        $sql .= $p->getDateAddHourExpression('test_datetime', 3) . ' AS add_hour, ';
-        $sql .= $p->getDateSubHourExpression('test_datetime', 3) . ' AS sub_hour, ';
-        $sql .= $p->getDateAddDaysExpression('test_datetime', 10) . ' AS add_days, ';
-        $sql .= $p->getDateSubDaysExpression('test_datetime', 10) . ' AS sub_days, ';
-        $sql .= $p->getDateAddWeeksExpression('test_datetime', 1) . ' AS add_weeks, ';
-        $sql .= $p->getDateSubWeeksExpression('test_datetime', 1) . ' AS sub_weeks, ';
-        $sql .= $p->getDateAddMonthExpression('test_datetime', 2) . ' AS add_month, ';
-        $sql .= $p->getDateSubMonthExpression('test_datetime', 2) . ' AS sub_month, ';
-        $sql .= $p->getDateAddQuartersExpression('test_datetime', 3) . ' AS add_quarters, ';
-        $sql .= $p->getDateSubQuartersExpression('test_datetime', 3) . ' AS sub_quarters, ';
-        $sql .= $p->getDateAddYearsExpression('test_datetime', 6) . ' AS add_years, ';
-        $sql .= $p->getDateSubYearsExpression('test_datetime', 6) . ' AS sub_years ';
-        $sql .= 'FROM fetch_table';
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddSecondsExpression('test_datetime', $interval);
+            },
+            1,
+            '2010-01-01 10:10:11',
+        );
+    }
 
-        $row = $this->connection->fetchAssociative($sql);
-        self::assertNotFalse($row);
-        $row = array_change_key_case($row, CASE_LOWER);
+    #[DataProvider('modeProvider')]
+    public function testDateSubSeconds(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubSecondsExpression('test_datetime', $interval);
+            },
+            1,
+            '2010-01-01 10:10:09',
+        );
+    }
 
-        self::assertEquals('2010-01-01 10:10:11', date('Y-m-d H:i:s', strtotime($row['add_seconds'])));
-        self::assertEquals('2010-01-01 10:10:09', date('Y-m-d H:i:s', strtotime($row['sub_seconds'])));
-        self::assertEquals('2010-01-01 10:15:10', date('Y-m-d H:i:s', strtotime($row['add_minutes'])));
-        self::assertEquals('2010-01-01 10:05:10', date('Y-m-d H:i:s', strtotime($row['sub_minutes'])));
-        self::assertEquals('2010-01-01 13:10', date('Y-m-d H:i', strtotime($row['add_hour'])));
-        self::assertEquals('2010-01-01 07:10', date('Y-m-d H:i', strtotime($row['sub_hour'])));
-        self::assertEquals('2010-01-11', date('Y-m-d', strtotime($row['add_days'])));
-        self::assertEquals('2009-12-22', date('Y-m-d', strtotime($row['sub_days'])));
-        self::assertEquals('2010-01-08', date('Y-m-d', strtotime($row['add_weeks'])));
-        self::assertEquals('2009-12-25', date('Y-m-d', strtotime($row['sub_weeks'])));
-        self::assertEquals('2010-03-01', date('Y-m-d', strtotime($row['add_month'])));
-        self::assertEquals('2009-11-01', date('Y-m-d', strtotime($row['sub_month'])));
-        self::assertEquals('2010-10-01', date('Y-m-d', strtotime($row['add_quarters'])));
-        self::assertEquals('2009-04-01', date('Y-m-d', strtotime($row['sub_quarters'])));
-        self::assertEquals('2016-01-01', date('Y-m-d', strtotime($row['add_years'])));
-        self::assertEquals('2004-01-01', date('Y-m-d', strtotime($row['sub_years'])));
+    #[DataProvider('modeProvider')]
+    public function testDateAddMinutes(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddMinutesExpression('test_datetime', $interval);
+            },
+            5,
+            '2010-01-01 10:15:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubMinutes(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubMinutesExpression('test_datetime', $interval);
+            },
+            5,
+            '2010-01-01 10:05:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddHours(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddHourExpression('test_datetime', $interval);
+            },
+            3,
+            '2010-01-01 13:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubHours(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubHourExpression('test_datetime', $interval);
+            },
+            3,
+            '2010-01-01 07:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddDays(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddDaysExpression('test_datetime', $interval);
+            },
+            10,
+            '2010-01-11 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubDays(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubDaysExpression('test_datetime', $interval);
+            },
+            10,
+            '2009-12-22 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddWeeks(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddWeeksExpression('test_datetime', $interval);
+            },
+            1,
+            '2010-01-08 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubWeeks(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubWeeksExpression('test_datetime', $interval);
+            },
+            1,
+            '2009-12-25 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddMonths(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddMonthExpression('test_datetime', $interval);
+            },
+            2,
+            '2010-03-01 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubMonths(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubMonthExpression('test_datetime', $interval);
+            },
+            2,
+            '2009-11-01 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddQuarters(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddQuartersExpression('test_datetime', $interval);
+            },
+            3,
+            '2010-10-01 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubQuarters(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubQuartersExpression('test_datetime', $interval);
+            },
+            3,
+            '2009-04-01 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateAddYears(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateAddYearsExpression('test_datetime', $interval);
+            },
+            6,
+            '2016-01-01 10:10:10',
+        );
+    }
+
+    #[DataProvider('modeProvider')]
+    public function testDateSubYears(callable $buildQuery, callable $bindParams): void
+    {
+        $this->assertDateExpression(
+            $buildQuery,
+            $bindParams,
+            static function (AbstractPlatform $platform, string $interval): string {
+                return $platform->getDateSubYearsExpression('test_datetime', $interval);
+            },
+            6,
+            '2004-01-01 10:10:10',
+        );
+    }
+
+    /**
+     * @param callable $buildQuery Builds the portion of the query representing the interval value
+     * @param callable $bindParams Binds the interval value to the statement
+     * @param callable $expression Builds the platform-specific interval expression
+     * @param int      $interval   Interval value
+     * @param string   $expected   Expected value
+     */
+    private function assertDateExpression(
+        callable $buildQuery,
+        callable $bindParams,
+        callable $expression,
+        int $interval,
+        string $expected,
+    ): void {
+        $connection = $this->connection;
+        $platform   = $connection->getDatabasePlatform();
+
+        $query = sprintf('SELECT %s FROM fetch_table', $expression($platform, $buildQuery($interval)));
+        $stmt  = $connection->prepare($query);
+        $bindParams($stmt, $interval);
+
+        $date = $stmt->executeQuery()->fetchOne();
+        self::assertNotFalse($date);
+
+        self::assertEquals($expected, date('Y-m-d H:i:s', strtotime($date)));
+    }
+
+    /** @return mixed[][] */
+    public static function modeProvider(): array
+    {
+        return [
+            'bind' => [
+                static function (int $interval): string {
+                    return '?';
+                },
+                static function (Statement $stmt, int $interval): void {
+                    $stmt->bindValue(1, $interval, ParameterType::INTEGER);
+                },
+            ],
+            'literal' => [
+                static function (int $interval): string {
+                    return sprintf('%d', $interval);
+                },
+                static function (Statement $stmt, int $interval): void {
+                },
+            ],
+            'expression' => [
+                static function (int $interval): string {
+                    return sprintf('(0 + %d)', $interval);
+                },
+                static function (Statement $stmt, int $interval): void {
+                },
+            ],
+        ];
     }
 
     public function testSqliteDateArithmeticWithDynamicInterval(): void
     {
         $platform = $this->connection->getDatabasePlatform();
 
-        if (! $platform instanceof SqlitePlatform) {
+        if (! $platform instanceof SQLitePlatform) {
             self::markTestSkipped('test is for sqlite only');
         }
 
@@ -442,7 +644,7 @@ class DataAccessTest extends FunctionalTestCase
         $table->addColumn('test_days', Types::INTEGER);
         $table->setPrimaryKey(['test_date']);
 
-        $sm = $this->connection->getSchemaManager();
+        $sm = $this->connection->createSchemaManager();
         $sm->createTable($table);
 
         $this->connection->insert('fetch_table_date_math', ['test_date' => '2010-01-01', 'test_days' => 10]);
@@ -468,9 +670,9 @@ class DataAccessTest extends FunctionalTestCase
         $sql .= $platform->getLocateExpression("'foo'", 'test_string') . ' AS locate5, ';
         $sql .= $platform->getLocateExpression("'barfoobaz'", 'test_string') . ' AS locate6, ';
         $sql .= $platform->getLocateExpression("'bar'", 'test_string') . ' AS locate7, ';
-        $sql .= $platform->getLocateExpression('test_string', "'oo'", 2) . ' AS locate8, ';
-        $sql .= $platform->getLocateExpression('test_string', "'oo'", 3) . ' AS locate9, ';
-        $sql .= $platform->getLocateExpression('test_string', "'foo'", 1) . ' AS locate10, ';
+        $sql .= $platform->getLocateExpression('test_string', "'oo'", '2') . ' AS locate8, ';
+        $sql .= $platform->getLocateExpression('test_string', "'oo'", '3') . ' AS locate9, ';
+        $sql .= $platform->getLocateExpression('test_string', "'foo'", '1') . ' AS locate10, ';
         $sql .= $platform->getLocateExpression('test_string', "'oo'", '1 + 1') . ' AS locate11 ';
         $sql .= 'FROM fetch_table';
 
@@ -493,43 +695,41 @@ class DataAccessTest extends FunctionalTestCase
         ], $row);
     }
 
-    public function testSqliteLocateEmulation(): void
+    #[DataProvider('substringExpressionProvider')]
+    public function testSubstringExpression(string $string, string $start, ?string $length, string $expected): void
     {
-        if (! TestUtil::isDriverOneOf('pdo_sqlite', 'sqlite3')) {
-            self::markTestSkipped('test is for SQLite only');
-        }
+        $platform = $this->connection->getDatabasePlatform();
 
-        $sql = <<< 'SQL'
-            SELECT
-                LOCATE(test_string, 'oo') AS locate1,
-                LOCATE(test_string, 'foo') AS locate2,
-                LOCATE(test_string, 'bar') AS locate3,
-                LOCATE(test_string, test_string) AS locate4,
-                LOCATE('foo', test_string) AS locate5,
-                LOCATE('barfoobaz', test_string) AS locate6,
-                LOCATE('bar', test_string) AS locate7,
-                LOCATE(test_string, 'oo', 2) AS locate8,
-                LOCATE(test_string, 'oo', 3) AS locate9,
-                LOCATE(test_string, 'foo', 1) AS locate10,
-                LOCATE(test_string, 'oo', 1 + 1) AS locate11
-            FROM fetch_table
-            SQL;
+        $query = $platform->getDummySelectSQL(
+            $platform->getSubstringExpression($string, $start, $length),
+        );
 
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/5749');
+        self::assertEquals($expected, $this->connection->fetchOne($query));
+    }
 
-        self::assertEquals([
-            'locate1' => 2,
-            'locate2' => 1,
-            'locate3' => 0,
-            'locate4' => 1,
-            'locate5' => 1,
-            'locate6' => 4,
-            'locate7' => 0,
-            'locate8' => 2,
-            'locate9' => 0,
-            'locate10' => 1,
-            'locate11' => 2,
-        ], $this->connection->fetchAssociative($sql));
+    /** @return mixed[][] */
+    public static function substringExpressionProvider(): iterable
+    {
+        return [
+            'start-no-length' => [
+                "'abcdef'",
+                '3',
+                null,
+                'cdef',
+            ],
+            'start-with-length' => [
+                "'abcdef'",
+                '2',
+                '4',
+                'bcde',
+            ],
+            'expressions' => [
+                "'abcdef'",
+                '1 + 1',
+                '1 + 1',
+                'bc',
+            ],
+        ];
     }
 
     public function testQuoteSQLInjection(): void
