@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Driver;
 
 use Doctrine\DBAL\Schema\Table;
@@ -38,6 +40,6 @@ class DBAL6024Test extends FunctionalTestCase
         $validationSchema = $schemaManager->introspectSchema();
         $validationTable  = $validationSchema->getTable($table->getName());
 
-        $this->assertNull($validationTable->getPrimaryKey());
+        self::assertNull($validationTable->getPrimaryKey());
     }
 }
