@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Driver\Mysqli;
 
 use Doctrine\DBAL\Driver\Exception;
@@ -50,7 +52,7 @@ class ConnectionTest extends FunctionalTestCase
         );
     }
 
-    /** @param mixed[] $driverOptions */
+    /** @param array<string, mixed> $driverOptions */
     private function getConnection(array $driverOptions): Connection
     {
         $params = TestUtil::getConnectionParams();
