@@ -1,33 +1,37 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Exception;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Types;
-use Throwable;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function array_merge;
 use function chmod;
 use function exec;
+use function extension_loaded;
 use function file_exists;
+use function func_get_args;
 use function posix_geteuid;
-use function posix_getpwuid;
+use function restore_error_handler;
+use function set_error_handler;
 use function sprintf;
 use function sys_get_temp_dir;
 use function touch;
 use function unlink;
 
-use const E_ALL;
 use const E_WARNING;
 use const PHP_OS_FAMILY;
 
-/** @psalm-import-type Params from DriverManager */
+/** @phpstan-import-type Params from DriverManager */
 class ExceptionTest extends FunctionalTestCase
 {
     public function testPrimaryConstraintViolationException(): void
@@ -53,7 +57,7 @@ class ExceptionTest extends FunctionalTestCase
 
     public function testTableExistsException(): void
     {
-        $schemaManager = $this->connection->getSchemaManager();
+        $schemaManager = $this->connection->createSchemaManager();
         $table         = new Table('alreadyexist_table');
         $table->addColumn('id', Types::INTEGER, []);
         $table->setPrimaryKey(['id']);
@@ -63,128 +67,6 @@ class ExceptionTest extends FunctionalTestCase
         $schemaManager->createTable($table);
     }
 
-    public function testForeignKeyConstraintViolationExceptionOnInsert(): void
-    {
-        $this->setUpForeignKeyConstraintViolationExceptionTest();
-
-        try {
-            $this->connection->insert('constraint_error_table', ['id' => 1]);
-            $this->connection->insert('owning_table', ['id' => 1, 'constraint_id' => 1]);
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->expectException(Exception\ForeignKeyConstraintViolationException::class);
-
-        try {
-            $this->connection->insert('owning_table', ['id' => 2, 'constraint_id' => 2]);
-        } catch (Exception\ForeignKeyConstraintViolationException $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->tearDownForeignKeyConstraintViolationExceptionTest();
-    }
-
-    public function testForeignKeyConstraintViolationExceptionOnUpdate(): void
-    {
-        $this->setUpForeignKeyConstraintViolationExceptionTest();
-
-        try {
-            $this->connection->insert('constraint_error_table', ['id' => 1]);
-            $this->connection->insert('owning_table', ['id' => 1, 'constraint_id' => 1]);
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->expectException(Exception\ForeignKeyConstraintViolationException::class);
-
-        try {
-            $this->connection->update('constraint_error_table', ['id' => 2], ['id' => 1]);
-        } catch (Exception\ForeignKeyConstraintViolationException $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->tearDownForeignKeyConstraintViolationExceptionTest();
-    }
-
-    public function testForeignKeyConstraintViolationExceptionOnDelete(): void
-    {
-        $this->setUpForeignKeyConstraintViolationExceptionTest();
-
-        try {
-            $this->connection->insert('constraint_error_table', ['id' => 1]);
-            $this->connection->insert('owning_table', ['id' => 1, 'constraint_id' => 1]);
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->expectException(Exception\ForeignKeyConstraintViolationException::class);
-
-        try {
-            $this->connection->delete('constraint_error_table', ['id' => 1]);
-        } catch (Exception\ForeignKeyConstraintViolationException $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->tearDownForeignKeyConstraintViolationExceptionTest();
-    }
-
-    public function testForeignKeyConstraintViolationExceptionOnTruncate(): void
-    {
-        $platform = $this->connection->getDatabasePlatform();
-
-        $this->setUpForeignKeyConstraintViolationExceptionTest();
-
-        try {
-            $this->connection->insert('constraint_error_table', ['id' => 1]);
-            $this->connection->insert('owning_table', ['id' => 1, 'constraint_id' => 1]);
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->expectException(Exception\ForeignKeyConstraintViolationException::class);
-
-        try {
-            $this->connection->executeStatement($platform->getTruncateTableSQL('constraint_error_table'));
-        } catch (Exception\ForeignKeyConstraintViolationException $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        } catch (Throwable $exception) {
-            $this->tearDownForeignKeyConstraintViolationExceptionTest();
-
-            throw $exception;
-        }
-
-        $this->tearDownForeignKeyConstraintViolationExceptionTest();
-    }
-
     public function testNotNullConstraintViolationException(): void
     {
         $table = new Table('notnull_table');
@@ -203,11 +85,24 @@ class ExceptionTest extends FunctionalTestCase
         $table->addColumn('id', Types::INTEGER, []);
         $this->dropAndCreateTable($table);
 
-        // prevent the PHPUnit error handler from handling the warning that db2_bind_param() may trigger
-        $this->iniSet('error_reporting', (string) (E_ALL & ~E_WARNING));
-
         $this->expectException(Exception\InvalidFieldNameException::class);
-        $this->connection->insert('bad_columnname_table', ['name' => 5]);
+
+        // prevent the PHPUnit error handler from handling the warning that db2_bind_param() may trigger
+        /** @var callable|null $previous */
+        $previous = null;
+        $previous = set_error_handler(static function (int $errno) use (&$previous): bool {
+            if (($errno & ~E_WARNING) === 0) {
+                return true;
+            }
+
+            return $previous !== null && $previous(...func_get_args());
+        });
+
+        try {
+            $this->connection->insert('bad_columnname_table', ['name' => 5]);
+        } finally {
+            restore_error_handler();
+        }
     }
 
     public function testNonUniqueFieldNameException(): void
@@ -253,7 +148,7 @@ class ExceptionTest extends FunctionalTestCase
 
     public function testConnectionExceptionSqLite(): void
     {
-        if (! ($this->connection->getDatabasePlatform() instanceof SqlitePlatform)) {
+        if (! ($this->connection->getDatabasePlatform() instanceof SQLitePlatform)) {
             self::markTestSkipped('Only fails this way on sqlite');
         }
 
@@ -269,7 +164,7 @@ class ExceptionTest extends FunctionalTestCase
         touch($filename);
         chmod($filename, $mode);
 
-        if ($this->isLinuxRoot()) {
+        if ($this->isPosixSuperUser()) {
             exec(sprintf('chattr +i %s', $filename));
         }
 
@@ -321,15 +216,14 @@ class ExceptionTest extends FunctionalTestCase
 
     /**
      * @param array<string, mixed> $params
-     * @psalm-param Params $params
-     *
-     * @dataProvider getConnectionParams
+     * @phpstan-param Params $params
      */
+    #[DataProvider('getConnectionParams')]
     private function testConnectionException(array $params): void
     {
         $platform = $this->connection->getDatabasePlatform();
 
-        if ($platform instanceof SqlitePlatform) {
+        if ($platform instanceof SQLitePlatform) {
             self::markTestSkipped('The SQLite driver does not use a network connection');
         }
 
@@ -337,7 +231,7 @@ class ExceptionTest extends FunctionalTestCase
         $conn   = DriverManager::getConnection($params);
 
         $this->expectException(Exception\ConnectionException::class);
-        $conn->connect();
+        $conn->executeQuery($platform->getDummySelectSQL());
     }
 
     /** @return array<int, array<int, mixed>> */
@@ -350,40 +244,14 @@ class ExceptionTest extends FunctionalTestCase
         ];
     }
 
-    private function setUpForeignKeyConstraintViolationExceptionTest(): void
+    private function isPosixSuperUser(): bool
     {
-        $schemaManager = $this->connection->getSchemaManager();
-
-        $table = new Table('constraint_error_table');
-        $table->addColumn('id', Types::INTEGER, []);
-        $table->setPrimaryKey(['id']);
-
-        $owningTable = new Table('owning_table');
-        $owningTable->addColumn('id', Types::INTEGER, []);
-        $owningTable->addColumn('constraint_id', Types::INTEGER, []);
-        $owningTable->setPrimaryKey(['id']);
-        $owningTable->addForeignKeyConstraint($table, ['constraint_id'], ['id']);
-
-        $schemaManager->createTable($table);
-        $schemaManager->createTable($owningTable);
-    }
-
-    private function tearDownForeignKeyConstraintViolationExceptionTest(): void
-    {
-        $schemaManager = $this->connection->getSchemaManager();
-
-        $schemaManager->dropTable('owning_table');
-        $schemaManager->dropTable('constraint_error_table');
-    }
-
-    private function isLinuxRoot(): bool
-    {
-        return PHP_OS_FAMILY !== 'Windows' && posix_getpwuid(posix_geteuid())['name'] === 'root';
+        return extension_loaded('posix') && posix_geteuid() === 0;
     }
 
     private function cleanupReadOnlyFile(string $filename): void
     {
-        if ($this->isLinuxRoot()) {
+        if ($this->isPosixSuperUser()) {
             exec(sprintf('chattr -i %s', $filename));
         }
 
