@@ -4,21 +4,22 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional;
 
-use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
+use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 class FetchBooleanTest extends FunctionalTestCase
 {
     protected function setUp(): void
     {
-        if ($this->connection->getDatabasePlatform() instanceof PostgreSQL94Platform) {
+        if ($this->connection->getDatabasePlatform() instanceof PostgreSQLPlatform) {
             return;
         }
 
         self::markTestSkipped('Only PostgreSQL supports boolean values natively');
     }
 
-    /** @dataProvider booleanLiteralProvider */
+    #[DataProvider('booleanLiteralProvider')]
     public function testBooleanConversionSqlLiteral(string $literal, bool $expected): void
     {
         self::assertSame([$expected], $this->connection->fetchNumeric(
