@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\Platforms\DB2Platform;
@@ -167,7 +169,7 @@ SQL;
         string $sql,
         ?int $limit,
         int $offset,
-        bool $deterministic = true
+        bool $deterministic = true,
     ): void {
         $p    = $this->connection->getDatabasePlatform();
         $data = [];
@@ -194,7 +196,7 @@ SQL;
         }
 
         if ($platform instanceof OraclePlatform) {
-            $this->markTestSkipped('Oracle cannot handle ORDER BY in subquery');
+            self::markTestSkipped('Oracle cannot handle ORDER BY in subquery');
         }
 
         $this->connection->insert('modify_limit_table2', ['test_int' => 3]);
