@@ -12,22 +12,25 @@ class AddColumnWithDefaultTest extends FunctionalTestCase
 {
     public function testAddColumnWithDefault(): void
     {
-        $schemaManager = $this->connection->getSchemaManager();
+        $schemaManager = $this->connection->createSchemaManager();
 
         $table = new Table('add_default_test');
 
-        $table->addColumn('original_field', Types::STRING);
+        $table->addColumn('original_field', Types::STRING, ['length' => 8]);
         $this->dropAndCreateTable($table);
 
         $this->connection->executeStatement("INSERT INTO add_default_test (original_field) VALUES ('one')");
 
-        $table->addColumn('new_field', Types::STRING, ['default' => 'DEFAULT']);
+        $table->addColumn('new_field', Types::STRING, [
+            'length' => 8,
+            'default' => 'DEFAULT',
+        ]);
 
-        $diff = $schemaManager->createComparator()->diffTable(
+        $diff = $schemaManager->createComparator()->compareTables(
             $schemaManager->introspectTable('add_default_test'),
             $table,
         );
-        self::assertNotFalse($diff);
+
         $schemaManager->alterTable($diff);
 
         $query  = 'SELECT original_field, new_field FROM add_default_test';
