@@ -1,15 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 
-use function array_keys;
-
 class AlterColumnTest extends FunctionalTestCase
 {
     public function testColumnPositionRetainedAfterAltering(): void
@@ -21,16 +20,20 @@ class AlterColumnTest extends FunctionalTestCase
         $this->dropAndCreateTable($table);
 
         $table->getColumn('c1')
-            ->setType(Type::getType(Types::STRING));
+            ->setType(Type::getType(Types::STRING))
+            ->setLength(16);
 
-        $sm         = $this->connection->createSchemaManager();
-        $comparator = new Comparator();
-        $diff       = $comparator->diffTable($sm->introspectTable('test_alter'), $table);
+        $sm   = $this->connection->createSchemaManager();
+        $diff = $sm->createComparator()
+            ->compareTables($sm->introspectTable('test_alter'), $table);
 
-        self::assertNotFalse($diff);
         $sm->alterTable($diff);
 
-        $table = $sm->introspectTable('test_alter');
-        self::assertSame(['c1', 'c2'], array_keys($table->getColumns()));
+        $table   = $sm->introspectTable('test_alter');
+        $columns = $table->getColumns();
+
+        self::assertCount(2, $columns);
+        self::assertEqualsIgnoringCase('c1', $columns[0]->getName());
+        self::assertEqualsIgnoringCase('c2', $columns[1]->getName());
     }
 }
