@@ -1,11 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
 
@@ -27,16 +27,12 @@ final class NewPrimaryKeyWithNewAutoIncrementColumnTest extends FunctionalTestCa
      * Before the fix for this problem this resulted in a database error: (at least on mysql)
      * SQLSTATE[42000]: Syntax error or access violation: 1075 Incorrect table definition; there can be only one auto
      * column and it must be defined as a key
-     *
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
      */
-    public function testAlterPrimaryKeyToAutoIncrementColumn(callable $comparatorFactory): void
+    public function testAlterPrimaryKeyToAutoIncrementColumn(): void
     {
         $this->dropTableIfExists('dbal2807');
 
-        $schemaManager = $this->connection->getSchemaManager();
+        $schemaManager = $this->connection->createSchemaManager();
         $schema        = $schemaManager->introspectSchema();
 
         $table = $schema->createTable('dbal2807');
@@ -51,8 +47,8 @@ final class NewPrimaryKeyWithNewAutoIncrementColumnTest extends FunctionalTestCa
         $newTable->dropPrimaryKey();
         $newTable->setPrimaryKey(['new_id']);
 
-        $diff = $comparatorFactory($schemaManager)
-            ->compare($schema, $newSchema);
+        $diff = $schemaManager->createComparator()
+            ->compareSchemas($schema, $newSchema);
 
         $schemaManager->alterSchema($diff);
 
@@ -61,9 +57,10 @@ final class NewPrimaryKeyWithNewAutoIncrementColumnTest extends FunctionalTestCa
 
         self::assertTrue($validationTable->hasColumn('new_id'));
         self::assertTrue($validationTable->getColumn('new_id')->getAutoincrement());
-        self::assertTrue($validationTable->hasPrimaryKey());
-        self::assertCount(1, $validationTable->getPrimaryKeyColumns());
-        self::assertArrayHasKey('new_id', $validationTable->getPrimaryKeyColumns());
+
+        $primaryKey = $validationTable->getPrimaryKey();
+        self::assertNotNull($primaryKey);
+        self::assertSame(['new_id'], $primaryKey->getColumns());
     }
 
     private function getPlatform(): AbstractPlatform
