@@ -1,11 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
 use Doctrine\DBAL\DriverManager;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Tools\DsnParser;
 use Doctrine\DBAL\Types\Types;
 
 class OtherSchemaTest extends FunctionalTestCase
@@ -13,12 +16,11 @@ class OtherSchemaTest extends FunctionalTestCase
     public function testATableCanBeCreatedInAnotherSchema(): void
     {
         $databasePlatform = $this->connection->getDatabasePlatform();
-        if (! ($databasePlatform instanceof SqlitePlatform)) {
+        if (! ($databasePlatform instanceof SQLitePlatform)) {
             self::markTestSkipped('This test requires SQLite');
         }
 
         $this->connection->executeStatement("ATTACH DATABASE '/tmp/test_other_schema.sqlite' AS other");
-        $databasePlatform->disableSchemaEmulation();
 
         $table = new Table('other.test_other_schema');
         $table->addColumn('id', Types::INTEGER);
@@ -28,8 +30,9 @@ class OtherSchemaTest extends FunctionalTestCase
         $this->connection->insert('other.test_other_schema', ['id' => 1]);
 
         self::assertEquals(1, $this->connection->fetchOne('SELECT COUNT(*) FROM other.test_other_schema'));
+        $dsnParser   = new DsnParser();
         $connection  = DriverManager::getConnection(
-            ['url' => 'sqlite:////tmp/test_other_schema.sqlite'],
+            $dsnParser->parse('sqlite3:////tmp/test_other_schema.sqlite'),
         );
         $onlineTable = $connection->createSchemaManager()->introspectTable('test_other_schema');
         self::assertCount(1, $onlineTable->getIndexes());
