@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
 use Doctrine\DBAL\Schema\Table;
@@ -27,9 +29,9 @@ class PlatformRestrictionsTest extends FunctionalTestCase
         $table->addColumn($columnName, Types::INTEGER, ['autoincrement' => true]);
         $table->setPrimaryKey([$columnName]);
         $this->dropAndCreateTable($table);
-        $createdTable = $this->connection->getSchemaManager()->introspectTable($tableName);
+        $createdTable = $this->connection->createSchemaManager()->introspectTable($tableName);
 
-        $this->assertTrue($createdTable->hasColumn($columnName));
-        $this->assertTrue($createdTable->hasPrimaryKey());
+        self::assertTrue($createdTable->hasColumn($columnName));
+        self::assertNotNull($createdTable->getPrimaryKey());
     }
 }
