@@ -1,15 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
 use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function key;
 
 class QuotingTest extends FunctionalTestCase
 {
-    /** @dataProvider stringLiteralProvider */
+    #[DataProvider('stringLiteralProvider')]
     public function testQuoteStringLiteral(string $string): void
     {
         $platform = $this->connection->getDatabasePlatform();
@@ -29,7 +32,7 @@ class QuotingTest extends FunctionalTestCase
         ];
     }
 
-    /** @dataProvider identifierProvider */
+    #[DataProvider('identifierProvider')]
     public function testQuoteIdentifier(string $identifier): void
     {
         $platform = $this->connection->getDatabasePlatform();
