@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\ColumnCase;
@@ -9,6 +11,7 @@ use Doctrine\DBAL\Portability\Middleware;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function array_keys;
 use function array_merge;
@@ -39,20 +42,16 @@ class PortabilityTest extends FunctionalTestCase
 
         $result = $this->connection
             ->prepare('SELECT * FROM portability_table')
-            ->execute();
+            ->executeQuery();
 
         while (($row = $result->fetchAssociative())) {
             $this->assertFetchResultRow($row);
         }
     }
 
-    /**
-     * @param 0|ColumnCase::LOWER|ColumnCase::UPPER $case
-     * @param list<string>                          $expected
-     *
-     * @dataProvider caseProvider
-     */
-    public function testCaseConversion(int $case, array $expected): void
+    /** @param list<string> $expected */
+    #[DataProvider('caseProvider')]
+    public function testCaseConversion(ColumnCase $case, array $expected): void
     {
         $this->connectWithPortability(Connection::PORTABILITY_FIX_CASE, $case);
         $this->createTable();
@@ -63,7 +62,25 @@ class PortabilityTest extends FunctionalTestCase
         self::assertSame($expected, array_keys($row));
     }
 
-    /** @return iterable<string, array{(ColumnCase::LOWER|ColumnCase::UPPER), list<string>}> */
+    /** @param list<string> $expected */
+    #[DataProvider('caseProvider')]
+    public function testCaseConversionColumnName(ColumnCase $case, array $expected): void
+    {
+        $this->connectWithPortability(Connection::PORTABILITY_FIX_CASE, $case);
+        $this->createTable();
+
+        $result = $this->connection->executeQuery('SELECT * FROM portability_table');
+
+        $actual = [];
+
+        foreach ($expected as $index => $name) {
+            $actual[$index] = $result->getColumnName($index);
+        }
+
+        self::assertSame($expected, $actual);
+    }
+
+    /** @return iterable<string, array{ColumnCase, list<string>}> */
     public static function caseProvider(): iterable
     {
         yield 'lower' => [ColumnCase::LOWER, ['test_int', 'test_string', 'test_null']];
@@ -93,14 +110,11 @@ class PortabilityTest extends FunctionalTestCase
         self::assertArrayNotHasKey(0, $row, 'The row should not contain numerical keys.');
     }
 
-    /**
-     * @param mixed[] $expected
-     *
-     * @dataProvider fetchColumnProvider
-     */
+    /** @param mixed[] $expected */
+    #[DataProvider('fetchColumnProvider')]
     public function testFetchColumn(string $column, array $expected): void
     {
-        $this->connectWithPortability(Connection::PORTABILITY_RTRIM, 0);
+        $this->connectWithPortability(Connection::PORTABILITY_RTRIM, null);
         $this->createTable();
 
         $result = $this->connection->executeQuery('SELECT ' . $column . ' FROM portability_table');
@@ -125,7 +139,7 @@ class PortabilityTest extends FunctionalTestCase
 
     public function testFetchAllNullColumn(): void
     {
-        $this->connectWithPortability(Connection::PORTABILITY_EMPTY_TO_NULL, 0);
+        $this->connectWithPortability(Connection::PORTABILITY_EMPTY_TO_NULL, null);
         $this->createTable();
 
         $column = $this->connection->fetchFirstColumn('SELECT Test_Null FROM portability_table');
@@ -135,12 +149,11 @@ class PortabilityTest extends FunctionalTestCase
 
     public function testGetDatabaseName(): void
     {
-        $this->connectWithPortability(Connection::PORTABILITY_EMPTY_TO_NULL, 0);
+        $this->connectWithPortability(Connection::PORTABILITY_EMPTY_TO_NULL, ColumnCase::LOWER);
         self::assertNotNull($this->connection->getDatabase());
     }
 
-     /** @param 0|ColumnCase::LOWER|ColumnCase::UPPER $case */
-    private function connectWithPortability(int $mode, int $case): void
+    private function connectWithPortability(int $mode, ?ColumnCase $case): void
     {
         // closing the default connection prior to 4.0.0 to prevent connection leak
         $this->connection->close();
@@ -160,8 +173,14 @@ class PortabilityTest extends FunctionalTestCase
     {
         $table = new Table('portability_table');
         $table->addColumn('Test_Int', Types::INTEGER);
-        $table->addColumn('Test_String', Types::STRING, ['fixed' => true, 'length' => 32]);
-        $table->addColumn('Test_Null', Types::STRING, ['notnull' => false]);
+        $table->addColumn('Test_String', Types::STRING, [
+            'fixed' => true,
+            'length' => 8,
+        ]);
+        $table->addColumn('Test_Null', Types::STRING, [
+            'length' => 1,
+            'notnull' => false,
+        ]);
         $table->setPrimaryKey(['Test_Int']);
 
         $this->dropAndCreateTable($table);
