@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\SQL\Builder;
 
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
@@ -41,7 +43,7 @@ class CreateAndDropSchemaObjectsSQLBuilderTest extends FunctionalTestCase
     private function introspectForeignKey(
         AbstractSchemaManager $schemaManager,
         string $tableName,
-        string $expectedForeignTableName
+        string $expectedForeignTableName,
     ): void {
         $foreignKeys = $schemaManager->listTableForeignKeys($tableName);
         self::assertCount(1, $foreignKeys);
