@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema\PostgreSQL;
 
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
@@ -36,7 +38,7 @@ final class SchemaTest extends FunctionalTestCase
             ['my_table'],
         );
 
-        $this->assertNotFalse($result);
-        $this->assertEquals('nextval(\'my_table_id_seq\'::regclass)', $result['column_default']);
+        self::assertNotFalse($result);
+        self::assertEquals('nextval(\'my_table_id_seq\'::regclass)', $result['column_default']);
     }
 }
