@@ -22,7 +22,6 @@ use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\Attributes\DataProvider;
 
 use function array_map;
-use function array_pop;
 use function count;
 use function sprintf;
 use function strtolower;
@@ -121,44 +120,6 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertFalse($tableFinal->getColumn('id')->getAutoincrement());
     }
 
-    public function testTableWithSchema(): void
-    {
-        $this->connection->executeStatement('CREATE SCHEMA nested');
-
-        $nestedRelatedTable = new Table('nested.schemarelated');
-        $column             = $nestedRelatedTable->addColumn('id', Types::INTEGER);
-        $column->setAutoincrement(true);
-        $nestedRelatedTable->setPrimaryKey(['id']);
-
-        $nestedSchemaTable = new Table('nested.schematable');
-        $column            = $nestedSchemaTable->addColumn('id', Types::INTEGER);
-        $column->setAutoincrement(true);
-        $nestedSchemaTable->setPrimaryKey(['id']);
-        $nestedSchemaTable->addForeignKeyConstraint($nestedRelatedTable->getName(), ['id'], ['id']);
-
-        $this->schemaManager->createTable($nestedRelatedTable);
-        $this->schemaManager->createTable($nestedSchemaTable);
-
-        $tableNames = $this->schemaManager->listTableNames();
-        self::assertContains('nested.schematable', $tableNames);
-
-        $tables = $this->schemaManager->listTables();
-        self::assertNotNull($this->findTableByName($tables, 'nested.schematable'));
-
-        $nestedSchemaTable = $this->schemaManager->introspectTable('nested.schematable');
-        self::assertTrue($nestedSchemaTable->hasColumn('id'));
-
-        $primaryKey = $nestedSchemaTable->getPrimaryKey();
-        self::assertNotNull($primaryKey);
-        self::assertEquals(['id'], $primaryKey->getColumns());
-
-        $relatedFks = $nestedSchemaTable->getForeignKeys();
-        self::assertCount(1, $relatedFks);
-        $relatedFk = array_pop($relatedFks);
-        self::assertNotNull($relatedFk);
-        self::assertEquals('nested.schemarelated', $relatedFk->getForeignTableName());
-    }
-
     public function testListSameTableNameColumnsWithDifferentSchema(): void
     {
         $this->connection->executeStatement('CREATE SCHEMA another');
