@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
 use Doctrine\DBAL\Schema\Table;
@@ -16,8 +18,8 @@ class DBAL168Test extends FunctionalTestCase
         $table->setPrimaryKey(['id']);
         $table->addForeignKeyConstraint('domains', ['parent_id'], ['id']);
 
-        $this->connection->getSchemaManager()->createTable($table);
-        $table = $this->connection->getSchemaManager()->introspectTable('domains');
+        $this->connection->createSchemaManager()->createTable($table);
+        $table = $this->connection->createSchemaManager()->introspectTable('domains');
 
         self::assertEquals('domains', $table->getName());
     }
