@@ -1,10 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
 use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Types\Types;
 
 class DBAL202Test extends FunctionalTestCase
 {
@@ -14,14 +17,14 @@ class DBAL202Test extends FunctionalTestCase
             self::markTestSkipped('Oracle only test');
         }
 
-        if ($this->connection->getSchemaManager()->tablesExist('DBAL202')) {
+        if ($this->connection->createSchemaManager()->tableExists('DBAL202')) {
             $this->connection->executeStatement('DELETE FROM DBAL202');
         } else {
             $table = new Table('DBAL202');
-            $table->addColumn('id', 'integer');
+            $table->addColumn('id', Types::INTEGER);
             $table->setPrimaryKey(['id']);
 
-            $this->connection->getSchemaManager()->createTable($table);
+            $this->connection->createSchemaManager()->createTable($table);
         }
     }
 
@@ -29,7 +32,7 @@ class DBAL202Test extends FunctionalTestCase
     {
         $stmt = $this->connection->prepare('INSERT INTO DBAL202 VALUES (8)');
         $this->connection->beginTransaction();
-        $stmt->execute();
+        $stmt->executeStatement();
         $this->connection->rollBack();
 
         self::assertEquals(0, $this->connection->fetchOne('SELECT COUNT(1) FROM DBAL202'));
@@ -39,7 +42,7 @@ class DBAL202Test extends FunctionalTestCase
     {
         $stmt = $this->connection->prepare('INSERT INTO DBAL202 VALUES (8)');
         $this->connection->beginTransaction();
-        $stmt->execute();
+        $stmt->executeStatement();
         $this->connection->commit();
 
         self::assertEquals(1, $this->connection->fetchOne('SELECT COUNT(1) FROM DBAL202'));
