@@ -1,10 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
-use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Platforms\SQLServer2012Platform;
+use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\SQLServerSchemaManager;
 use Doctrine\DBAL\Types\DecimalType;
 use Doctrine\DBAL\Types\Types;
@@ -15,20 +16,14 @@ class DBAL461Test extends TestCase
 {
     public function testIssue(): void
     {
-        $configuration = $this->createStub(Configuration::class);
-        $configuration->method('getDisableTypeComments')->willReturn(false);
-
-        $conn = $this->createMock(Connection::class);
-        $conn->method('getConfiguration')->willReturn($configuration);
-
-        $platform = new SQLServer2012Platform();
+        $conn     = $this->createMock(Connection::class);
+        $platform = new SQLServerPlatform();
         $platform->registerDoctrineTypeMapping('numeric', Types::DECIMAL);
 
         $schemaManager = new SQLServerSchemaManager($conn, $platform);
 
         $reflectionMethod = new ReflectionMethod($schemaManager, '_getPortableTableColumnDefinition');
-        $reflectionMethod->setAccessible(true);
-        $column = $reflectionMethod->invoke($schemaManager, [
+        $column           = $reflectionMethod->invoke($schemaManager, [
             'type' => 'numeric(18,0)',
             'length' => null,
             'default' => null,
@@ -37,7 +32,6 @@ class DBAL461Test extends TestCase
             'precision' => 0,
             'autoincrement' => false,
             'collation' => 'foo',
-            'comment' => null,
         ]);
 
         self::assertInstanceOf(DecimalType::class, $column->getType());
