@@ -1,10 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
-use Doctrine\DBAL\Schema\AbstractSchemaManager;
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
@@ -20,12 +20,7 @@ class DBAL510Test extends FunctionalTestCase
         self::markTestSkipped('PostgreSQL only test');
     }
 
-    /**
-     * @param callable(AbstractSchemaManager):Comparator $comparatorFactory
-     *
-     * @dataProvider \Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils::comparatorProvider
-     */
-    public function testSearchPathSchemaChanges(callable $comparatorFactory): void
+    public function testSearchPathSchemaChanges(): void
     {
         $table = new Table('dbal510tbl');
         $table->addColumn('id', Types::INTEGER);
@@ -36,9 +31,10 @@ class DBAL510Test extends FunctionalTestCase
         $schemaManager = $this->connection->createSchemaManager();
         $onlineTable   = $schemaManager->introspectTable('dbal510tbl');
 
-        $comparator = $comparatorFactory($schemaManager);
-        $diff       = $comparator->diffTable($onlineTable, $table);
-
-        self::assertFalse($diff);
+        self::assertTrue(
+            $schemaManager->createComparator()
+                ->compareTables($onlineTable, $table)
+                ->isEmpty(),
+        );
     }
 }
