@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional;
 
 use DateTime;
@@ -8,7 +10,7 @@ use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
-use stdClass;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function str_repeat;
 
@@ -16,12 +18,14 @@ class TypeConversionTest extends FunctionalTestCase
 {
     private static int $typeCounter = 0;
 
-    /** @psalm-suppress DeprecatedConstant */
     protected function setUp(): void
     {
         $table = new Table('type_conversion');
         $table->addColumn('id', Types::INTEGER, ['notnull' => false]);
-        $table->addColumn('test_string', Types::STRING, ['notnull' => false]);
+        $table->addColumn('test_string', Types::STRING, [
+            'length' => 16,
+            'notnull' => false,
+        ]);
         $table->addColumn('test_boolean', Types::BOOLEAN, ['notnull' => false]);
         $table->addColumn('test_bigint', Types::BIGINT, ['notnull' => false]);
         $table->addColumn('test_smallint', Types::BIGINT, ['notnull' => false]);
@@ -30,22 +34,17 @@ class TypeConversionTest extends FunctionalTestCase
         $table->addColumn('test_date', Types::DATE_MUTABLE, ['notnull' => false]);
         $table->addColumn('test_time', Types::TIME_MUTABLE, ['notnull' => false]);
         $table->addColumn('test_text', Types::TEXT, ['notnull' => false]);
-        $table->addColumn('test_array', Types::ARRAY, ['notnull' => false]);
         $table->addColumn('test_json', Types::JSON, ['notnull' => false]);
-        $table->addColumn('test_object', Types::OBJECT, ['notnull' => false]);
         $table->addColumn('test_float', Types::FLOAT, ['notnull' => false]);
+        $table->addColumn('test_smallfloat', Types::SMALLFLOAT, ['notnull' => false]);
         $table->addColumn('test_decimal', Types::DECIMAL, ['notnull' => false, 'scale' => 2, 'precision' => 10]);
         $table->setPrimaryKey(['id']);
 
         $this->dropAndCreateTable($table);
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider booleanProvider
-     */
-    public function testIdempotentConversionToBoolean(string $type, $originalValue): void
+    #[DataProvider('booleanProvider')]
+    public function testIdempotentConversionToBoolean(string $type, mixed $originalValue): void
     {
         $dbValue = $this->processValue($type, $originalValue);
 
@@ -62,12 +61,8 @@ class TypeConversionTest extends FunctionalTestCase
         ];
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider integerProvider
-     */
-    public function testIdempotentConversionToInteger(string $type, $originalValue): void
+    #[DataProvider('integerProvider')]
+    public function testIdempotentConversionToInteger(string $type, mixed $originalValue): void
     {
         $dbValue = $this->processValue($type, $originalValue);
 
@@ -83,12 +78,8 @@ class TypeConversionTest extends FunctionalTestCase
         ];
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider floatProvider
-     */
-    public function testIdempotentConversionToFloat(string $type, $originalValue): void
+    #[DataProvider('floatProvider')]
+    public function testIdempotentConversionToFloat(string $type, mixed $originalValue): void
     {
         $dbValue = $this->processValue($type, $originalValue);
 
@@ -101,15 +92,12 @@ class TypeConversionTest extends FunctionalTestCase
     {
         return [
             'float' => [Types::FLOAT, 1.5],
+            'smallfloat' => [Types::SMALLFLOAT, 1.5],
         ];
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider toStringProvider
-     */
-    public function testIdempotentConversionToString(string $type, $originalValue): void
+    #[DataProvider('toStringProvider')]
+    public function testIdempotentConversionToString(string $type, mixed $originalValue): void
     {
         if ($type === Types::TEXT && TestUtil::isDriverOneOf('pdo_oci')) {
             // inserting BLOBs as streams on Oracle requires Oracle-specific SQL syntax which is currently not supported
@@ -132,62 +120,12 @@ class TypeConversionTest extends FunctionalTestCase
         ];
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider toArrayProvider
-     */
-    public function testIdempotentConversionToArray(string $type, $originalValue): void
+    public function testIdempotentConversionToArray(): void
     {
-        $dbValue = $this->processValue($type, $originalValue);
-
-        self::assertIsArray($dbValue);
-        self::assertEquals($originalValue, $dbValue);
+        self::assertEquals(['foo' => 'bar'], $this->processValue('json', ['foo' => 'bar']));
     }
 
-    /**
-     * @return mixed[][]
-     *
-     * @psalm-suppress DeprecatedConstant
-     */
-    public static function toArrayProvider(): iterable
-    {
-        return [
-            'array' => [Types::ARRAY, ['foo' => 'bar']],
-            'json' => [Types::JSON, ['foo' => 'bar']],
-        ];
-    }
-
-    /**
-     * @param mixed $originalValue
-     *
-     * @dataProvider toObjectProvider
-     */
-    public function testIdempotentConversionToObject(string $type, $originalValue): void
-    {
-        $dbValue = $this->processValue($type, $originalValue);
-
-        self::assertIsObject($dbValue);
-        self::assertEquals($originalValue, $dbValue);
-    }
-
-    /**
-     * @return mixed[][]
-     *
-     * @psalm-suppress DeprecatedConstant
-     */
-    public static function toObjectProvider(): iterable
-    {
-        $obj      = new stdClass();
-        $obj->foo = 'bar';
-        $obj->bar = 'baz';
-
-        return [
-            'object' => [Types::OBJECT, $obj],
-        ];
-    }
-
-    /** @dataProvider toDateTimeProvider */
+    #[DataProvider('toDateTimeProvider')]
     public function testIdempotentConversionToDateTime(string $type, DateTime $originalValue): void
     {
         $dbValue = $this->processValue($type, $originalValue);
@@ -216,12 +154,7 @@ class TypeConversionTest extends FunctionalTestCase
         ];
     }
 
-    /**
-     * @param mixed $originalValue
-     *
-     * @return mixed
-     */
-    private function processValue(string $type, $originalValue)
+    private function processValue(string $type, mixed $originalValue): mixed
     {
         $columnName     = 'test_' . $type;
         $typeInstance   = Type::getType($type);
