@@ -282,172 +282,6 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
         self::assertEquals('LONGBLOB', $this->platform->getBlobTypeDeclarationSQL([]));
     }
 
-    public function testAlterTableAddPrimaryKey(): void
-    {
-        $table = new Table('alter_table_add_pk');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('foo', Types::INTEGER);
-        $table->addIndex(['id'], 'idx_id');
-
-        $diffTable = clone $table;
-
-        $diffTable->dropIndex('idx_id');
-        $diffTable->setPrimaryKey(['id']);
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertEquals(
-            ['DROP INDEX idx_id ON alter_table_add_pk', 'ALTER TABLE alter_table_add_pk ADD PRIMARY KEY (id)'],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
-    public function testAlterPrimaryKeyWithAutoincrementColumn(): void
-    {
-        $table = new Table('alter_primary_key');
-        $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $table->addColumn('foo', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
-
-        $diffTable = clone $table;
-
-        $diffTable->dropPrimaryKey();
-        $diffTable->setPrimaryKey(['foo']);
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertEquals(
-            [
-                'ALTER TABLE alter_primary_key MODIFY id INT NOT NULL',
-                'DROP INDEX `primary` ON alter_primary_key',
-                'ALTER TABLE alter_primary_key ADD PRIMARY KEY (foo)',
-            ],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
-    public function testDropPrimaryKeyWithAutoincrementColumn(): void
-    {
-        $table = new Table('drop_primary_key');
-        $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $table->addColumn('foo', Types::INTEGER);
-        $table->addColumn('bar', Types::INTEGER);
-        $table->setPrimaryKey(['id', 'foo']);
-
-        $diffTable = clone $table;
-
-        $diffTable->dropPrimaryKey();
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertEquals(
-            [
-                'ALTER TABLE drop_primary_key MODIFY id INT NOT NULL',
-                'DROP INDEX `primary` ON drop_primary_key',
-            ],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
-    public function testDropNonAutoincrementColumnFromCompositePrimaryKeyWithAutoincrementColumn(): void
-    {
-        $table = new Table('tbl');
-        $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $table->addColumn('foo', Types::INTEGER);
-        $table->addColumn('bar', Types::INTEGER);
-        $table->setPrimaryKey(['id', 'foo']);
-
-        $diffTable = clone $table;
-
-        $diffTable->dropPrimaryKey();
-        $diffTable->setPrimaryKey(['id']);
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertSame(
-            [
-                'ALTER TABLE tbl MODIFY id INT NOT NULL',
-                'DROP INDEX `primary` ON tbl',
-                'ALTER TABLE tbl ADD PRIMARY KEY (id)',
-            ],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
-    public function testAddNonAutoincrementColumnToPrimaryKeyWithAutoincrementColumn(): void
-    {
-        $table = new Table('tbl');
-        $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $table->addColumn('foo', Types::INTEGER);
-        $table->addColumn('bar', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
-
-        $diffTable = clone $table;
-
-        $diffTable->dropPrimaryKey();
-        $diffTable->setPrimaryKey(['id', 'foo']);
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertSame(
-            [
-                'ALTER TABLE tbl MODIFY id INT NOT NULL',
-                'DROP INDEX `primary` ON tbl',
-                'ALTER TABLE tbl ADD PRIMARY KEY (id, foo)',
-            ],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
-    public function testAddAutoIncrementPrimaryKey(): void
-    {
-        $keyTable = new Table('foo');
-        $keyTable->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
-        $keyTable->addColumn('baz', Types::STRING, ['length' => 32]);
-        $keyTable->setPrimaryKey(['id']);
-
-        $oldTable = new Table('foo');
-        $oldTable->addColumn('baz', Types::STRING, ['length' => 32]);
-
-        $diff = $this->createComparator()
-            ->compareTables($oldTable, $keyTable);
-
-        $sql = $this->platform->getAlterTableSQL($diff);
-
-        self::assertEquals(['ALTER TABLE foo ADD id INT AUTO_INCREMENT NOT NULL, ADD PRIMARY KEY (id)'], $sql);
-    }
-
-    public function testAlterPrimaryKeyWithNewColumn(): void
-    {
-        $table = new Table('yolo');
-        $table->addColumn('pkc1', Types::INTEGER);
-        $table->addColumn('col_a', Types::INTEGER);
-        $table->setPrimaryKey(['pkc1']);
-
-        $diffTable = clone $table;
-
-        $diffTable->addColumn('pkc2', Types::INTEGER);
-        $diffTable->dropPrimaryKey();
-        $diffTable->setPrimaryKey(['pkc1', 'pkc2']);
-
-        $diff = $this->createComparator()
-            ->compareTables($table, $diffTable);
-
-        self::assertSame(
-            [
-                'DROP INDEX `primary` ON yolo',
-                'ALTER TABLE yolo ADD pkc2 INT NOT NULL',
-                'ALTER TABLE yolo ADD PRIMARY KEY (pkc1, pkc2)',
-            ],
-            $this->platform->getAlterTableSQL($diff),
-        );
-    }
-
     public function testInitializesDoctrineTypeMappings(): void
     {
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('binary'));
