@@ -1,9 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Platforms\MySQL;
 
+use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\Comparator;
+use Doctrine\DBAL\Platforms\MySQL\DefaultTableOptions;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use Doctrine\DBAL\Tests\Schema\AbstractComparatorTestCase;
 
@@ -13,12 +17,9 @@ class ComparatorTest extends AbstractComparatorTestCase
     {
         $this->comparator = new Comparator(
             new MySQLPlatform(),
-            new class implements CollationMetadataProvider {
-                public function getCollationCharset(string $collation): ?string
-                {
-                    return null;
-                }
-            },
+            self::createStub(CharsetMetadataProvider::class),
+            self::createStub(CollationMetadataProvider::class),
+            new DefaultTableOptions('utf8mb4', 'utf8mb4_general_ci'),
         );
     }
 }
