@@ -1,20 +1,21 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Platforms;
 
 use Doctrine\DBAL\Exception;
+use Doctrine\DBAL\Exception\InvalidColumnDeclaration;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Schema\Column;
-use Doctrine\DBAL\Schema\ColumnDiff;
-use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
-use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 use function sprintf;
 use function strtoupper;
@@ -23,52 +24,6 @@ use function uniqid;
 /** @extends AbstractPlatformTestCase<OraclePlatform> */
 class OraclePlatformTest extends AbstractPlatformTestCase
 {
-    /** @return mixed[][] */
-    public static function dataValidIdentifiers(): iterable
-    {
-        return [
-            ['a'],
-            ['foo'],
-            ['Foo'],
-            ['Foo123'],
-            ['Foo#bar_baz$'],
-            ['"a"'],
-            ['"1"'],
-            ['"foo_bar"'],
-            ['"@$%&!"'],
-        ];
-    }
-
-    /** @dataProvider dataValidIdentifiers */
-    public function testValidIdentifiers(string $identifier): void
-    {
-        $platform = $this->createPlatform();
-        $platform->assertValidIdentifier($identifier);
-
-        $this->expectNotToPerformAssertions();
-    }
-
-    /** @return mixed[][] */
-    public static function dataInvalidIdentifiers(): iterable
-    {
-        return [
-            ['1'],
-            ['abc&'],
-            ['abc-def'],
-            ['"'],
-            ['"foo"bar"'],
-        ];
-    }
-
-    /** @dataProvider dataInvalidIdentifiers */
-    public function testInvalidIdentifiers(string $identifier): void
-    {
-        $this->expectException(Exception::class);
-
-        $platform = $this->createPlatform();
-        $platform->assertValidIdentifier($identifier);
-    }
-
     public function createPlatform(): AbstractPlatform
     {
         return new OraclePlatform();
@@ -99,7 +54,6 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
     public function testGeneratesSqlSnippets(): void
     {
-        self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter());
         self::assertEquals(
             'column1 || column2 || column3',
             $this->platform->getConcatExpression('column1', 'column2', 'column3'),
@@ -159,29 +113,6 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testGeneratesTypeDeclarationsForStrings(): void
-    {
-        self::assertEquals(
-            'CHAR(10)',
-            $this->platform->getStringTypeDeclarationSQL(
-                ['length' => 10, 'fixed' => true],
-            ),
-        );
-        self::assertEquals(
-            'VARCHAR2(50)',
-            $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
-        );
-        self::assertEquals(
-            'VARCHAR2(255)',
-            $this->platform->getStringTypeDeclarationSQL([]),
-        );
-    }
-
-    public function testPrefersIdentityColumns(): void
-    {
-        self::assertFalse($this->platform->prefersIdentityColumns());
-    }
-
     public function testSupportsIdentityColumns(): void
     {
         self::assertFalse($this->platform->supportsIdentityColumns());
@@ -212,14 +143,11 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         return 'ALTER TABLE test ADD FOREIGN KEY (fk_name_id) REFERENCES other_table (id)';
     }
 
-    /**
-     * @param mixed[] $options
-     *
-     * @dataProvider getGeneratesAdvancedForeignKeyOptionsSQLData
-     */
+    /** @param mixed[] $options */
+    #[DataProvider('getGeneratesAdvancedForeignKeyOptionsSQLData')]
     public function testGeneratesAdvancedForeignKeyOptionsSQL(array $options, string $expectedSql): void
     {
-        $foreignKey = new ForeignKeyConstraint(['foo'], 'foreign_table', ['bar'], null, $options);
+        $foreignKey = new ForeignKeyConstraint(['foo'], 'foreign_table', ['bar'], '', $options);
 
         self::assertSame($expectedSql, $this->platform->getAdvancedForeignKeyOptionsSQL($foreignKey));
     }
@@ -251,60 +179,13 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    public function testModifyLimitQuery(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 0);
-        self::assertEquals('SELECT a.* FROM (SELECT * FROM user) a WHERE ROWNUM <= 10', $sql);
-    }
-
-    public function testModifyLimitQueryWithEmptyOffset(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10);
-        self::assertEquals('SELECT a.* FROM (SELECT * FROM user) a WHERE ROWNUM <= 10', $sql);
-    }
-
-    public function testModifyLimitQueryWithNonEmptyOffset(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 10);
-
-        self::assertEquals(
-            'SELECT * FROM ('
-                . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a WHERE ROWNUM <= 20'
-                . ') WHERE doctrine_rownum >= 11',
-            $sql,
-        );
-    }
-
-    public function testModifyLimitQueryWithEmptyLimit(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', null, 10);
-
-        self::assertEquals(
-            'SELECT * FROM ('
-                . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a'
-                . ') WHERE doctrine_rownum >= 11',
-            $sql,
-        );
-    }
-
-    public function testModifyLimitQueryWithAscOrderBy(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user ORDER BY username ASC', 10);
-        self::assertEquals('SELECT a.* FROM (SELECT * FROM user ORDER BY username ASC) a WHERE ROWNUM <= 10', $sql);
-    }
-
-    public function testModifyLimitQueryWithDescOrderBy(): void
-    {
-        $sql = $this->platform->modifyLimitQuery('SELECT * FROM user ORDER BY username DESC', 10);
-        self::assertEquals('SELECT a.* FROM (SELECT * FROM user ORDER BY username DESC) a WHERE ROWNUM <= 10', $sql);
-    }
-
     public function testGenerateTableWithAutoincrement(): void
     {
         $columnName = strtoupper('id' . uniqid());
         $tableName  = strtoupper('table' . uniqid());
         $table      = new Table($tableName);
-        $column     = $table->addColumn($columnName, Types::INTEGER);
+
+        $column = $table->addColumn($columnName, Types::INTEGER);
         $column->setAutoincrement(true);
 
         self::assertSame([
@@ -350,7 +231,6 @@ BEGIN
       WHILE (last_InsertID > last_Sequence) LOOP
          SELECT %s_SEQ.NEXTVAL INTO last_Sequence FROM DUAL;
       END LOOP;
-      SELECT %s_SEQ.NEXTVAL INTO last_Sequence FROM DUAL;
    END IF;
 END;
 SQL
@@ -364,46 +244,10 @@ SQL
                 $tableName,
                 $columnName,
                 $tableName,
-                $tableName,
             ),
         ], $this->platform->getCreateTableSQL($table));
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getCreateTableColumnCommentsSQL(): array
-    {
-        return [
-            'CREATE TABLE test (id NUMBER(10) NOT NULL, PRIMARY KEY(id))',
-            "COMMENT ON COLUMN test.id IS 'This is a comment'",
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getCreateTableColumnTypeCommentsSQL(): array
-    {
-        return [
-            'CREATE TABLE test (id NUMBER(10) NOT NULL, data CLOB NOT NULL, PRIMARY KEY(id))',
-            "COMMENT ON COLUMN test.data IS '(DC2Type:array)'",
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getAlterTableColumnCommentsSQL(): array
-    {
-        return [
-            'ALTER TABLE mytable ADD (quota NUMBER(10) NOT NULL)',
-            "COMMENT ON COLUMN mytable.quota IS 'A comment'",
-            "COMMENT ON COLUMN mytable.foo IS ''",
-            "COMMENT ON COLUMN mytable.baz IS 'B comment'",
-        ];
-    }
-
     public function getBitAndComparisonExpressionSql(string $value1, string $value2): string
     {
         return 'BITAND(' . $value1 . ', ' . $value2 . ')';
@@ -464,45 +308,6 @@ SQL
         ];
     }
 
-    public function testAlterTableNotNULL(): void
-    {
-        $tableDiff                          = new TableDiff('mytable');
-        $tableDiff->changedColumns['foo']   = new ColumnDiff(
-            'foo',
-            new Column(
-                'foo',
-                Type::getType(Types::STRING),
-                ['default' => 'bla', 'notnull' => true],
-            ),
-            ['type'],
-        );
-        $tableDiff->changedColumns['bar']   = new ColumnDiff(
-            'bar',
-            new Column(
-                'baz',
-                Type::getType(Types::STRING),
-                ['default' => 'bla', 'notnull' => true],
-            ),
-            ['type', 'notnull'],
-        );
-        $tableDiff->changedColumns['metar'] = new ColumnDiff(
-            'metar',
-            new Column(
-                'metar',
-                Type::getType(Types::STRING),
-                ['length' => 2000, 'notnull' => false],
-            ),
-            ['notnull'],
-        );
-
-        $expectedSql = [
-            "ALTER TABLE mytable MODIFY (foo VARCHAR2(255) DEFAULT 'bla', baz VARCHAR2(255) DEFAULT 'bla' NOT NULL, "
-                . 'metar VARCHAR2(2000) DEFAULT NULL NULL)',
-        ];
-
-        self::assertEquals($expectedSql, $this->platform->getAlterTableSQL($tableDiff));
-    }
-
     public function testInitializesDoctrineTypeMappings(): void
     {
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('long raw'));
@@ -513,61 +318,71 @@ SQL
 
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('date'));
         self::assertSame(Types::DATE_MUTABLE, $this->platform->getDoctrineTypeMapping('date'));
+
+        self::assertTrue($this->platform->hasDoctrineTypeMappingFor('real'));
+        self::assertSame(Types::SMALLFLOAT, $this->platform->getDoctrineTypeMapping('real'));
     }
 
-    protected function getBinaryMaxLength(): int
+    public function testGetVariableLengthStringTypeDeclarationSQLNoLength(): void
     {
-        return 2000;
+        $this->expectException(InvalidColumnDeclaration::class);
+
+        parent::testGetVariableLengthStringTypeDeclarationSQLNoLength();
     }
 
-    public function testReturnsBinaryTypeDeclarationSQL(): void
+    protected function getExpectedVariableLengthStringTypeDeclarationSQLWithLength(): string
     {
-        self::assertSame('RAW(255)', $this->platform->getBinaryTypeDeclarationSQL([]));
-        self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['length' => 0]));
-        self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['length' => 2000]));
-
-        self::assertSame('RAW(255)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true]));
-        self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 0]));
-
-        self::assertSame(
-            'RAW(2000)',
-            $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2000]),
-        );
+        return 'VARCHAR2(16)';
     }
 
-    public function testReturnsBinaryTypeLongerThanMaxDeclarationSQL(): void
+    public function testGetFixedLengthBinaryTypeDeclarationSQLNoLength(): void
     {
-        self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 2001]));
-        self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2001]));
+        $this->expectException(InvalidColumnDeclaration::class);
+
+        parent::testGetFixedLengthBinaryTypeDeclarationSQLNoLength();
+    }
+
+    public function getExpectedFixedLengthBinaryTypeDeclarationSQLWithLength(): string
+    {
+        return 'RAW(16)';
+    }
+
+    public function testGetVariableLengthBinaryTypeDeclarationSQLNoLength(): void
+    {
+        $this->expectException(InvalidColumnDeclaration::class);
+
+        parent::testGetVariableLengthBinaryTypeDeclarationSQLNoLength();
+    }
+
+    public function getExpectedVariableLengthBinaryTypeDeclarationSQLWithLength(): string
+    {
+        return 'RAW(16)';
     }
 
     public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType(): void
     {
         $table1 = new Table('mytable');
-        $table1->addColumn('column_varbinary', Types::BINARY);
-        $table1->addColumn('column_binary', Types::BINARY, ['fixed' => true]);
+        $table1->addColumn('column_varbinary', Types::BINARY, ['length' => 32]);
+        $table1->addColumn('column_binary', Types::BINARY, [
+            'fixed' => true,
+            'length' => 32,
+        ]);
 
         $table2 = new Table('mytable');
-        $table2->addColumn('column_varbinary', Types::BINARY, ['fixed' => true]);
-        $table2->addColumn('column_binary', Types::BINARY);
+        $table2->addColumn('column_varbinary', Types::BINARY, [
+            'fixed' => true,
+            'length' => 32,
+        ]);
+        $table2->addColumn('column_binary', Types::BINARY, ['length' => 32]);
 
-        self::assertFalse((new Comparator($this->platform))->diffTable($table1, $table2));
+        self::assertTrue(
+            $this->createComparator()
+                ->compareTables($table1, $table2)
+                ->isEmpty(),
+        );
     }
 
-    public function testUsesSequenceEmulatedIdentityColumns(): void
-    {
-        self::assertTrue($this->platform->usesSequenceEmulatedIdentityColumns());
-    }
-
-    public function testReturnsIdentitySequenceName(): void
-    {
-        self::assertSame('MYTABLE_SEQ', $this->platform->getIdentitySequenceName('mytable', 'mycolumn'));
-        self::assertSame('"mytable_SEQ"', $this->platform->getIdentitySequenceName('"mytable"', 'mycolumn'));
-        self::assertSame('MYTABLE_SEQ', $this->platform->getIdentitySequenceName('mytable', '"mycolumn"'));
-        self::assertSame('"mytable_SEQ"', $this->platform->getIdentitySequenceName('"mytable"', '"mycolumn"'));
-    }
-
-    /** @dataProvider dataCreateSequenceWithCache */
+    #[DataProvider('dataCreateSequenceWithCache')]
     public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
         $sequence = new Sequence('foo', 1, 1, $cacheSize);
@@ -603,32 +418,6 @@ SQL
         ];
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    protected function getQuotedAlterTableRenameColumnSQL(): array
-    {
-        return [
-            'ALTER TABLE mytable RENAME COLUMN unquoted1 TO unquoted',
-            'ALTER TABLE mytable RENAME COLUMN unquoted2 TO "where"',
-            'ALTER TABLE mytable RENAME COLUMN unquoted3 TO "foo"',
-            'ALTER TABLE mytable RENAME COLUMN "create" TO reserved_keyword',
-            'ALTER TABLE mytable RENAME COLUMN "table" TO "from"',
-            'ALTER TABLE mytable RENAME COLUMN "select" TO "bar"',
-            'ALTER TABLE mytable RENAME COLUMN quoted1 TO quoted',
-            'ALTER TABLE mytable RENAME COLUMN quoted2 TO "and"',
-            'ALTER TABLE mytable RENAME COLUMN quoted3 TO "baz"',
-        ];
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    protected function getQuotedAlterTableChangeColumnLengthSQL(): array
-    {
-        self::markTestIncomplete('Not implemented yet');
-    }
-
     /**
      * {@inheritDoc}
      */
@@ -648,29 +437,13 @@ SQL
         ];
     }
 
-    protected function getQuotesDropForeignKeySQL(): string
-    {
-        return 'ALTER TABLE "table" DROP CONSTRAINT "select"';
-    }
-
     public function testReturnsGuidTypeDeclarationSQL(): void
     {
         self::assertSame('CHAR(36)', $this->platform->getGuidTypeDeclarationSQL([]));
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getAlterTableRenameColumnSQL(): array
-    {
-        return ['ALTER TABLE foo RENAME COLUMN bar TO baz'];
-    }
-
-    /**
-     * @param string[] $expectedSql
-     *
-     * @dataProvider getReturnsDropAutoincrementSQL
-     */
+    /** @param string[] $expectedSql */
+    #[DataProvider('getReturnsDropAutoincrementSQL')]
     public function testReturnsDropAutoincrementSQL(string $table, array $expectedSql): void
     {
         self::assertSame($expectedSql, $this->platform->getDropAutoincrementSql($table));
@@ -724,11 +497,9 @@ SQL
         $table1 = new Table('"foo"', [new Column('"bar"', Type::getType(Types::INTEGER))]);
         $table2 = new Table('"foo"', [new Column('"bar"', Type::getType(Types::INTEGER), ['comment' => 'baz'])]);
 
-        $comparator = new Comparator();
+        $tableDiff = $this->createComparator()
+            ->compareTables($table1, $table2);
 
-        $tableDiff = $comparator->diffTable($table1, $table2);
-
-        self::assertInstanceOf(TableDiff::class, $tableDiff);
         self::assertSame(
             ['COMMENT ON COLUMN "foo"."bar" IS \'baz\''],
             $this->platform->getAlterTableSQL($tableDiff),
@@ -767,7 +538,6 @@ BEGIN
       WHILE (last_InsertID > last_Sequence) LOOP
          SELECT "test_SEQ".NEXTVAL INTO last_Sequence FROM DUAL;
       END LOOP;
-      SELECT "test_SEQ".NEXTVAL INTO last_Sequence FROM DUAL;
    END IF;
 END;
 EOD;
@@ -775,70 +545,6 @@ EOD;
         self::assertEquals($createTriggerStatement, $sql[3]);
     }
 
-    /** @dataProvider getReturnsGetListTableColumnsSQL */
-    public function testReturnsGetListTableColumnsSQL(?string $database, string $expectedSql): void
-    {
-        // note: this assertion is a bit strict, as it compares a full SQL string.
-        // Should this break in future, then please try to reduce the matching to substring matching while reworking
-        // the tests
-        self::assertEquals($expectedSql, $this->platform->getListTableColumnsSQL('"test"', $database));
-    }
-
-    /** @return mixed[][] */
-    public static function getReturnsGetListTableColumnsSQL(): iterable
-    {
-        return [
-            [
-                null,
-                <<<'SQL'
-SELECT   c.*,
-         (
-             SELECT d.comments
-             FROM   user_col_comments d
-             WHERE  d.TABLE_NAME = c.TABLE_NAME
-             AND    d.COLUMN_NAME = c.COLUMN_NAME
-         ) AS comments
-FROM     user_tab_columns c
-WHERE    c.table_name = 'test'
-ORDER BY c.column_id
-SQL
-,
-            ],
-            [
-                '/',
-                <<<'SQL'
-SELECT   c.*,
-         (
-             SELECT d.comments
-             FROM   user_col_comments d
-             WHERE  d.TABLE_NAME = c.TABLE_NAME
-             AND    d.COLUMN_NAME = c.COLUMN_NAME
-         ) AS comments
-FROM     user_tab_columns c
-WHERE    c.table_name = 'test'
-ORDER BY c.column_id
-SQL
-,
-            ],
-            [
-                'scott',
-                <<<'SQL'
-SELECT   c.*,
-         (
-             SELECT d.comments
-             FROM   all_col_comments d
-             WHERE  d.TABLE_NAME = c.TABLE_NAME AND d.OWNER = c.OWNER
-             AND    d.COLUMN_NAME = c.COLUMN_NAME
-         ) AS comments
-FROM     all_tab_columns c
-WHERE    c.table_name = 'test' AND c.owner = 'SCOTT'
-ORDER BY c.column_id
-SQL
-,
-            ],
-        ];
-    }
-
     protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL(): string
     {
         return 'CONSTRAINT "select" UNIQUE (foo)';
@@ -878,46 +584,6 @@ SQL
         );
     }
 
-    public function testQuotesTableNameInListTableIndexesSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesTableNameInListTableForeignKeysSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesTableNameInListTableConstraintsSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\'",
-            $this->platform->getListTableConstraintsSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesTableNameInListTableColumnsSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\"),
-        );
-    }
-
-    public function testQuotesDatabaseNameInListTableColumnsSQL(): void
-    {
-        self::assertStringContainsStringIgnoringCase(
-            "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL('foo_table', "Foo'Bar\\"),
-        );
-    }
-
     /** @return array<int, array{string, array<string, mixed>}> */
     public static function asciiStringSqlDeclarationDataProvider(): array
     {
@@ -927,9 +593,12 @@ SQL
         ];
     }
 
-    protected function getLimitOffsetCastToIntExpectedQuery(): string
+    /** @return array<string, array{array<string>, string}> */
+    public static function getEnumDeclarationSQLProvider(): array
     {
-        return 'SELECT * FROM (SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a WHERE ROWNUM <= 3)'
-            . ' WHERE doctrine_rownum >= 3';
+        return [
+            'single value' => [['foo'], 'VARCHAR2(3)'],
+            'multiple values' => [['foo', 'bar1'], 'VARCHAR2(4)'],
+        ];
     }
 }
