@@ -848,8 +848,8 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
     protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
-            "EXEC sp_rename N'[table].[create]', N'[select]', N'INDEX'",
-            "EXEC sp_rename N'[table].[foo]', N'[bar]', N'INDEX'",
+            "EXEC sp_rename N'[table].[create]', N'select', N'INDEX'",
+            "EXEC sp_rename N'[table].[foo]', N'bar', N'INDEX'",
         ];
     }
 
@@ -867,8 +867,8 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
     protected function getQuotedAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
-            "EXEC sp_rename N'[schema].[table].[create]', N'[select]', N'INDEX'",
-            "EXEC sp_rename N'[schema].[table].[foo]', N'[bar]', N'INDEX'",
+            "EXEC sp_rename N'[schema].[table].[create]', N'select', N'INDEX'",
+            "EXEC sp_rename N'[schema].[table].[foo]', N'bar', N'INDEX'",
         ];
     }
 
@@ -1124,4 +1124,13 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals('DATETIMEOFFSET(6)', $this->platform->getDateTimeTzTypeDeclarationSQL([]));
     }
+
+    /** @return array<string, array{array<string>, string}> */
+    public static function getEnumDeclarationSQLProvider(): array
+    {
+        return [
+            'single value' => [['foo'], 'NVARCHAR(3)'],
+            'multiple values' => [['foo', 'bar1'], 'NVARCHAR(4)'],
+        ];
+    }
 }
