@@ -2,10 +2,10 @@
 
 declare(strict_types=1);
 
-namespace Doctrine\Tests\DBAL\Portability;
+namespace Doctrine\DBAL\Tests\Portability;
 
 use Doctrine\DBAL\Platforms\OraclePlatform;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Portability\Connection;
 use Doctrine\DBAL\Portability\OptimizeFlags;
 use PHPUnit\Framework\TestCase;
@@ -28,7 +28,7 @@ class OptimizeFlagsTest extends TestCase
 
     public function testAnotherPlatform(): void
     {
-        $flags = ($this->optimizeFlags)(new SqlitePlatform(), Connection::PORTABILITY_ALL);
+        $flags = ($this->optimizeFlags)(new SQLitePlatform(), Connection::PORTABILITY_ALL);
 
         self::assertSame(Connection::PORTABILITY_ALL, $flags);
     }
