@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Query;
 
 use Doctrine\DBAL\ArrayParameterType;
@@ -10,22 +12,21 @@ use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Query\Expression\ExpressionBuilder;
 use Doctrine\DBAL\Query\QueryBuilder;
 use Doctrine\DBAL\Query\QueryException;
+use Doctrine\DBAL\Query\UnionType;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\SQL\Builder\DefaultSelectSQLBuilder;
-use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\SQL\Builder\DefaultUnionSQLBuilder;
 use Doctrine\DBAL\Types\Types;
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
 use function hex2bin;
 
+/** @phpstan-import-type WrapperParameterTypeArray from Connection */
 class QueryBuilderTest extends TestCase
 {
-    use VerifyDeprecations;
-
-    /** @var Connection&MockObject */
-    protected Connection $conn;
+    protected Connection&MockObject $conn;
 
     protected function setUp(): void
     {
@@ -33,12 +34,20 @@ class QueryBuilderTest extends TestCase
 
         $expressionBuilder = new ExpressionBuilder($this->conn);
 
-        $this->conn->method('getExpressionBuilder')
+        $this->conn->method('createExpressionBuilder')
            ->willReturn($expressionBuilder);
 
         $platform = $this->createMock(AbstractPlatform::class);
+        $platform->method('getUnionSelectPartSQL')
+            ->willReturnArgument(0);
+        $platform->method('getUnionAllSQL')
+            ->willReturn('UNION ALL');
+        $platform->method('getUnionDistinctSQL')
+            ->willReturn('UNION');
         $platform->method('createSelectSQLBuilder')
             ->willReturn(new DefaultSelectSQLBuilder($platform, null, null));
+        $platform->method('createUnionSQLBuilder')
+            ->willReturn(new DefaultUnionSQLBuilder($platform));
 
         $this->conn->method('getDatabasePlatform')
             ->willReturn($platform);
@@ -210,28 +219,6 @@ class QueryBuilderTest extends TestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id', (string) $qb);
     }
 
-    public function testSelectEmptyGroupBy(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-
-        $qb->select('u.*', 'p.*')
-           ->groupBy([])
-           ->from('users', 'u');
-
-        self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
-    }
-
-    public function testSelectEmptyAddGroupBy(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-
-        $qb->select('u.*', 'p.*')
-           ->addGroupBy([])
-           ->from('users', 'u');
-
-        self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
-    }
-
     public function testSelectAddGroupBy(): void
     {
         $qb = new QueryBuilder($this->conn);
@@ -353,7 +340,7 @@ class QueryBuilderTest extends TestCase
            ->from('users', 'u')
            ->orderBy('u.name');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC', (string) $qb);
+        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name', (string) $qb);
     }
 
     public function testSelectAddOrderBy(): void
@@ -365,7 +352,7 @@ class QueryBuilderTest extends TestCase
            ->orderBy('u.name')
            ->addOrderBy('u.username', 'DESC');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC, u.username DESC', (string) $qb);
+        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name, u.username DESC', (string) $qb);
     }
 
     public function testSelectAddAddOrderBy(): void
@@ -377,7 +364,7 @@ class QueryBuilderTest extends TestCase
            ->addOrderBy('u.name')
            ->addOrderBy('u.username', 'DESC');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC, u.username DESC', (string) $qb);
+        self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name, u.username DESC', (string) $qb);
     }
 
     public function testEmptySelect(): void
@@ -386,7 +373,9 @@ class QueryBuilderTest extends TestCase
         $qb2 = $qb->select();
 
         self::assertSame($qb, $qb2);
-        self::assertEquals(QueryBuilder::SELECT, $qb->getType());
+
+        $this->expectException(QueryException::class);
+        $qb->getSQL();
     }
 
     public function testSelectAddSelect(): void
@@ -400,15 +389,6 @@ class QueryBuilderTest extends TestCase
         self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
     }
 
-    public function testEmptyAddSelect(): void
-    {
-        $qb  = new QueryBuilder($this->conn);
-        $qb2 = $qb->addSelect();
-
-        self::assertSame($qb, $qb2);
-        self::assertEquals(QueryBuilder::SELECT, $qb->getType());
-    }
-
     public function testSelectMultipleFrom(): void
     {
         $qb = new QueryBuilder($this->conn);
@@ -422,17 +402,6 @@ class QueryBuilderTest extends TestCase
     }
 
     public function testUpdate(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-        $qb->update('users', 'u')
-           ->set('u.foo', '?')
-           ->set('u.bar', '?');
-
-        self::assertEquals(QueryBuilder::UPDATE, $qb->getType());
-        self::assertEquals('UPDATE users u SET u.foo = ?, u.bar = ?', (string) $qb);
-    }
-
-    public function testUpdateWithoutAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->update('users')
@@ -445,56 +414,28 @@ class QueryBuilderTest extends TestCase
     public function testUpdateWhere(): void
     {
         $qb = new QueryBuilder($this->conn);
-        $qb->update('users', 'u')
-           ->set('u.foo', '?')
-           ->where('u.foo = ?');
+        $qb->update('users')
+           ->set('foo', '?')
+           ->where('foo = ?');
 
-        self::assertEquals('UPDATE users u SET u.foo = ? WHERE u.foo = ?', (string) $qb);
-    }
-
-    public function testEmptyUpdate(): void
-    {
-        $qb  = new QueryBuilder($this->conn);
-        $qb2 = $qb->update();
-
-        self::assertEquals(QueryBuilder::UPDATE, $qb->getType());
-        self::assertSame($qb2, $qb);
+        self::assertEquals('UPDATE users SET foo = ? WHERE foo = ?', (string) $qb);
     }
 
     public function testDelete(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-        $qb->delete('users', 'u');
-
-        self::assertEquals(QueryBuilder::DELETE, $qb->getType());
-        self::assertEquals('DELETE FROM users u', (string) $qb);
-    }
-
-    public function testDeleteWithoutAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->delete('users');
 
-        self::assertEquals(QueryBuilder::DELETE, $qb->getType());
         self::assertEquals('DELETE FROM users', (string) $qb);
     }
 
     public function testDeleteWhere(): void
     {
         $qb = new QueryBuilder($this->conn);
-        $qb->delete('users', 'u')
+        $qb->delete('users')
            ->where('u.foo = ?');
 
-        self::assertEquals('DELETE FROM users u WHERE u.foo = ?', (string) $qb);
-    }
-
-    public function testEmptyDelete(): void
-    {
-        $qb  = new QueryBuilder($this->conn);
-        $qb2 = $qb->delete();
-
-        self::assertEquals(QueryBuilder::DELETE, $qb->getType());
-        self::assertSame($qb2, $qb);
+        self::assertEquals('DELETE FROM users WHERE u.foo = ?', (string) $qb);
     }
 
     public function testInsertValues(): void
@@ -508,7 +449,6 @@ class QueryBuilderTest extends TestCase
                 ],
             );
 
-        self::assertEquals(QueryBuilder::INSERT, $qb->getType());
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
@@ -529,7 +469,6 @@ class QueryBuilderTest extends TestCase
                 ],
             );
 
-        self::assertEquals(QueryBuilder::INSERT, $qb->getType());
         self::assertEquals('INSERT INTO users (bar, foo) VALUES(?, ?)', (string) $qb);
     }
 
@@ -541,7 +480,6 @@ class QueryBuilderTest extends TestCase
             ->setValue('bar', '?')
             ->setValue('foo', '?');
 
-        self::assertEquals(QueryBuilder::INSERT, $qb->getType());
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
@@ -554,48 +492,15 @@ class QueryBuilderTest extends TestCase
             )
             ->setValue('bar', '?');
 
-        self::assertEquals(QueryBuilder::INSERT, $qb->getType());
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
-    public function testEmptyInsert(): void
-    {
-        $qb  = new QueryBuilder($this->conn);
-        $qb2 = $qb->insert();
-
-        self::assertEquals(QueryBuilder::INSERT, $qb->getType());
-        self::assertSame($qb2, $qb);
-    }
-
-    public function testGetConnection(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-        self::assertSame($this->conn, $qb->getConnection());
-    }
-
-    public function testGetState(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-
-        self::assertEquals(QueryBuilder::STATE_CLEAN, $qb->getState());
-
-        $qb->select('u.*')->from('users', 'u');
-
-        self::assertEquals(QueryBuilder::STATE_DIRTY, $qb->getState());
-
-        $sql1 = $qb->getSQL();
-
-        self::assertEquals(QueryBuilder::STATE_CLEAN, $qb->getState());
-        self::assertEquals($sql1, $qb->getSQL());
-    }
-
-    /** @dataProvider maxResultsProvider */
+    #[DataProvider('maxResultsProvider')]
     public function testSetMaxResults(?int $maxResults): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->setMaxResults($maxResults);
 
-        self::assertEquals(QueryBuilder::STATE_DIRTY, $qb->getState());
         self::assertEquals($maxResults, $qb->getMaxResults());
     }
 
@@ -613,7 +518,6 @@ class QueryBuilderTest extends TestCase
         $qb = new QueryBuilder($this->conn);
         $qb->setFirstResult(10);
 
-        self::assertEquals(QueryBuilder::STATE_DIRTY, $qb->getState());
         self::assertEquals(10, $qb->getFirstResult());
     }
 
@@ -631,82 +535,23 @@ class QueryBuilderTest extends TestCase
         return $qb;
     }
 
-    public function testResetQueryParts(): void
-    {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryParts(['distinct', 'where', 'orderBy']);
-
-        self::assertEquals('SELECT u.* FROM users u', (string) $qb);
-    }
-
-    public function testLegacyResetSelect(): void
-    {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('select')->addSelect('u.name');
-
-        self::assertEquals('SELECT DISTINCT u.name FROM users u WHERE u.name = ? ORDER BY u.name ASC', (string) $qb);
-    }
-
-    public function testLegacyResetDistinct(): void
-    {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('distinct');
-
-        self::assertEquals('SELECT u.* FROM users u WHERE u.name = ? ORDER BY u.name ASC', (string) $qb);
-    }
-
     public function testResetDistinct(): void
     {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectNoDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->distinct(false);
+        $qb = $this->prepareQueryBuilderToReset()->distinct(false);
 
         self::assertEquals('SELECT u.* FROM users u WHERE u.name = ? ORDER BY u.name ASC', (string) $qb);
     }
 
-    public function testLegacyResetWhere(): void
-    {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('where');
-
-        self::assertEquals('SELECT DISTINCT u.* FROM users u ORDER BY u.name ASC', (string) $qb);
-    }
-
     public function testResetWhere(): void
     {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectNoDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetWhere();
+        $qb = $this->prepareQueryBuilderToReset()->resetWhere();
 
         self::assertEquals('SELECT DISTINCT u.* FROM users u ORDER BY u.name ASC', (string) $qb);
     }
 
-    public function testLegacyResetOrderBy(): void
-    {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('orderBy');
-
-        self::assertEquals('SELECT DISTINCT u.* FROM users u WHERE u.name = ?', (string) $qb);
-    }
-
     public function testResetOrderBy(): void
     {
-        $qb = $this->prepareQueryBuilderToReset();
-
-        $this->expectNoDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetOrderBy();
+        $qb = $this->prepareQueryBuilderToReset()->resetOrderBy();
 
         self::assertEquals('SELECT DISTINCT u.* FROM users u WHERE u.name = ?', (string) $qb);
     }
@@ -728,25 +573,9 @@ class QueryBuilderTest extends TestCase
         return $qb;
     }
 
-    public function testLegacyResetHaving(): void
-    {
-        $qb = $this->prepareGroupedQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('having');
-
-        self::assertEquals(
-            'SELECT u.country, COUNT(*) FROM users u GROUP BY u.country ORDER BY COUNT(*) DESC',
-            (string) $qb,
-        );
-    }
-
     public function testResetHaving(): void
     {
-        $qb = $this->prepareGroupedQueryBuilderToReset();
-
-        $this->expectNoDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetHaving();
+        $qb = $this->prepareGroupedQueryBuilderToReset()->resetHaving();
 
         self::assertEquals(
             'SELECT u.country, COUNT(*) FROM users u GROUP BY u.country ORDER BY COUNT(*) DESC',
@@ -754,25 +583,9 @@ class QueryBuilderTest extends TestCase
         );
     }
 
-    public function testLegacyResetGroupBy(): void
-    {
-        $qb = $this->prepareGroupedQueryBuilderToReset();
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetQueryPart('groupBy');
-
-        self::assertEquals(
-            'SELECT u.country, COUNT(*) FROM users u HAVING COUNT(*) > ? ORDER BY COUNT(*) DESC',
-            (string) $qb,
-        );
-    }
-
     public function testResetGroupBy(): void
     {
-        $qb = $this->prepareGroupedQueryBuilderToReset();
-
-        $this->expectNoDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6193');
-        $qb->resetGroupBy();
+        $qb = $this->prepareGroupedQueryBuilderToReset()->resetGroupBy();
 
         self::assertEquals(
             'SELECT u.country, COUNT(*) FROM users u HAVING COUNT(*) > ? ORDER BY COUNT(*) DESC',
@@ -832,7 +645,7 @@ class QueryBuilderTest extends TestCase
 
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage(
-            "The given alias 'invalid' is not part of any FROM or JOIN clause table. "
+            'The given alias "invalid" is not part of any FROM or JOIN clause table. '
                 . 'The currently registered aliases are: news, nv.',
         );
         self::assertEquals('', $qb->getSQL());
@@ -938,16 +751,13 @@ class QueryBuilderTest extends TestCase
 
         $qb->setParameter(':test', (object) 1);
 
-        $qbClone = clone $qb;
+        $clone = clone $qb;
 
-        self::assertEquals((string) $qb, (string) $qbClone);
+        self::assertEquals((string) $qb, (string) $clone);
 
         $qb->andWhere('u.id = 1');
 
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6179');
-
-        self::assertNotSame($qb->getQueryParts(), $qbClone->getQueryParts());
-        self::assertNotSame($qb->getParameters(), $qbClone->getParameters());
+        self::assertNotSame($qb->getParameters(), $clone->getParameters());
     }
 
     public function testSimpleSelectWithoutTableAlias(): void
@@ -960,6 +770,16 @@ class QueryBuilderTest extends TestCase
         self::assertEquals('SELECT id FROM users', (string) $qb);
     }
 
+    public function testSimpleSelectWithMatchingTableAlias(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('users', 'users');
+
+        self::assertEquals('SELECT id FROM users', (string) $qb);
+    }
+
     public function testSelectWithSimpleWhereWithoutTableAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
@@ -1110,42 +930,24 @@ class QueryBuilderTest extends TestCase
 
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage(
-            "The given alias 'a' is not unique in FROM and JOIN clause table. The currently registered aliases are: a.",
+            'The given alias "a" is not unique in FROM and JOIN clause table. The currently registered aliases are: a.',
         );
 
         $qb->getSQL();
     }
 
-    public function testExecuteSelect(): void
-    {
-        $qb = new QueryBuilder($this->conn);
-
-        $this->conn
-            ->expects($this->any())
-            ->method('executeQuery')
-            ->willReturn($this->createMock(Result::class));
-
-        $result = $qb
-            ->select('id')
-            ->from('foo')
-            ->execute();
-
-        self::assertInstanceOf(Result::class, $result);
-    }
-
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchAssociative(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1169,18 +971,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchNumeric(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1204,18 +1005,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @param WrapperParameterTypeArray        $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchOne(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1239,18 +1039,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchAllAssociative(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1285,18 +1084,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchAllNumeric(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1331,18 +1129,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchAllKeyValue(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1377,18 +1174,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchAllAssociativeIndexed(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1427,18 +1223,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testFetchFirstColumn(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
@@ -1473,14 +1268,14 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @return iterable<
+     * @phpstan-return iterable<
      *     string,
      *     array{
      *          string,
      *          string,
      *          string,
      *          list<mixed>|array<string, mixed>,
-     *          array<int, int|string|Type|null>|array<string, int|string|Type|null>,
+     *          WrapperParameterTypeArray,
      *          string
      *  }>
      */
@@ -1524,31 +1319,30 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $params
+     * @phpstan-param WrapperParameterTypeArray $types
      */
+    #[DataProvider('fetchProvider')]
     public function testExecuteQuery(
         string $select,
         string $from,
         string $where,
-        array $parameters,
-        array $parameterTypes,
-        string $expectedSql
+        array $params,
+        array $types,
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $mockedResult = $this->createMock(Result::class);
 
         $this->conn->expects(self::once())
             ->method('executeQuery')
-            ->with($expectedSql, $parameters, $parameterTypes, null)
+            ->with($expectedSql, $params, $types)
             ->willReturn($mockedResult);
 
         $results = $qb->select($select)
             ->from($from)
             ->where($where)
-            ->setParameters($parameters, $parameterTypes)
+            ->setParameters($params, $types)
             ->executeQuery();
 
         self::assertSame(
@@ -1558,18 +1352,17 @@ class QueryBuilderTest extends TestCase
     }
 
     /**
-     * @param list<mixed>|array<string, mixed>                                     $parameters
-     * @param array<int, int|string|Type|null>|array<string, int|string|Type|null> $parameterTypes
-     *
-     * @dataProvider fetchProvider
+     * @param list<mixed>|array<string, mixed> $parameters
+     * @phpstan-param WrapperParameterTypeArray $parameterTypes
      */
+    #[DataProvider('fetchProvider')]
     public function testExecuteQueryWithResultCaching(
         string $select,
         string $from,
         string $where,
         array $parameters,
         array $parameterTypes,
-        string $expectedSql
+        string $expectedSql,
     ): void {
         $qb           = new QueryBuilder($this->conn);
         $qcp          = new QueryCacheProfile(300);
@@ -1626,4 +1419,78 @@ class QueryBuilderTest extends TestCase
             $results,
         );
     }
+
+    public function testUnionOnlyThrowException(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one');
+
+        $this->expectException(QueryException::class);
+        $this->expectExceptionMessage(
+            'Insufficient UNION parts give, need at least 2. '
+            . 'Please use union() and addUnion() to set enough UNION parts.',
+        );
+
+        $qb->getSQL();
+    }
+
+    public function testUnionWAllAndLimitClauseReturnsUnionAllQuery(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one')
+            ->addUnion('SELECT 2 as field_one', UnionType::ALL)
+            ->setMaxResults(10)
+            ->setFirstResult(10);
+
+        self::assertSame('SELECT 1 AS field_one UNION ALL SELECT 2 as field_one LIMIT 10 OFFSET 10', $qb->getSQL());
+    }
+
+    public function testUnionAllWithOrderByReturnsUnionAllQueryWithOrderBy(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one')
+            ->addUnion('SELECT 2 as field_one', UnionType::ALL)
+            ->orderBy('field_one', 'ASC');
+
+        self::assertSame('SELECT 1 AS field_one UNION ALL SELECT 2 as field_one ORDER BY field_one ASC', $qb->getSQL());
+    }
+
+    public function testOnlyAddUnionThrowQueryException(): void
+    {
+        $this->expectException(QueryException::class);
+
+        $qb = new QueryBuilder($this->conn);
+        $qb->addUnion('SELECT 1 AS field_one', UnionType::DISTINCT);
+    }
+
+    public function testUnionAndAddUnionReturnsUnionQuery(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one')
+            ->addUnion('SELECT 2 as field_one', UnionType::DISTINCT);
+
+        self::assertSame('SELECT 1 AS field_one UNION SELECT 2 as field_one', $qb->getSQL());
+    }
+
+    public function testUnionIsDistinctByDefault(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one')
+            ->addUnion('SELECT 2 as field_one');
+
+        self::assertSame('SELECT 1 AS field_one UNION SELECT 2 as field_one', $qb->getSQL());
+    }
+
+    public function testUnionAndOrderByReturnsUnionQueryWithOrderBy(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+        $qb->union('SELECT 1 AS field_one')
+            ->addUnion('SELECT 2 as field_one', UnionType::DISTINCT)
+            ->orderBy('field_one', 'ASC');
+
+        self::assertSame(
+            'SELECT 1 AS field_one UNION SELECT 2 as field_one ORDER BY field_one ASC',
+            $qb->getSQL(),
+        );
+    }
 }
