@@ -1,10 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Schema\Platforms;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\MySQL;
+use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider;
+use Doctrine\DBAL\Platforms\MySQL\DefaultTableOptions;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Table;
@@ -28,7 +32,7 @@ class MySQLSchemaTest extends TestCase
 
         $sqls = [];
         foreach ($tableOld->getForeignKeys() as $fk) {
-            $sqls[] = $this->platform->getCreateForeignKeySQL($fk, $tableOld);
+            $sqls[] = $this->platform->getCreateForeignKeySQL($fk, $tableOld->getQuotedName($this->platform));
         }
 
         self::assertEquals(
@@ -40,8 +44,7 @@ class MySQLSchemaTest extends TestCase
         );
     }
 
-    /** @dataProvider comparatorProvider */
-    public function testClobNoAlterTable(Comparator $comparator): void
+    public function testClobNoAlterTable(): void
     {
         $tableOld = new Table('test');
         $tableOld->addColumn('id', Types::INTEGER);
@@ -50,8 +53,8 @@ class MySQLSchemaTest extends TestCase
 
         $tableNew->setPrimaryKey(['id']);
 
-        $diff = $comparator->diffTable($tableOld, $tableNew);
-        self::assertNotFalse($diff);
+        $diff = $this->createComparator()
+            ->compareTables($tableOld, $tableNew);
 
         $sql = $this->platform->getAlterTableSQL($diff);
 
@@ -61,23 +64,13 @@ class MySQLSchemaTest extends TestCase
         );
     }
 
-    /** @return iterable<string,array{Comparator}> */
-    public static function comparatorProvider(): iterable
+    private function createComparator(): Comparator
     {
-        yield 'Generic comparator' => [
-            new Comparator(),
-        ];
-
-        yield 'MySQL comparator' => [
-            new MySQL\Comparator(
-                new MySQLPlatform(),
-                new class implements CollationMetadataProvider {
-                    public function getCollationCharset(string $collation): ?string
-                    {
-                        return null;
-                    }
-                },
-            ),
-        ];
+        return new MySQL\Comparator(
+            new MySQLPlatform(),
+            self::createStub(CharsetMetadataProvider::class),
+            self::createStub(CollationMetadataProvider::class),
+            new DefaultTableOptions('utf8mb4', 'utf8mb4_general_ci'),
+        );
     }
 }
