@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Schema;
 
 use Doctrine\DBAL\Schema\Schema;
@@ -7,13 +9,10 @@ use Doctrine\DBAL\Schema\SchemaConfig;
 use Doctrine\DBAL\Schema\SchemaException;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
-use Doctrine\DBAL\Schema\Visitor\AbstractVisitor;
-use Doctrine\DBAL\Schema\Visitor\Visitor;
 use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\TestCase;
-use ReflectionProperty;
 
-use function current;
+use function array_shift;
 use function strlen;
 
 class SchemaTest extends TestCase
@@ -27,9 +26,7 @@ class SchemaTest extends TestCase
 
         self::assertTrue($schema->hasTable($tableName));
 
-        $tables = $schema->getTables();
-        self::assertArrayHasKey($tableName, $tables);
-        self::assertSame($table, $tables[$tableName]);
+        self::assertSame([$table], $schema->getTables());
         self::assertSame($table, $schema->getTable($tableName));
         self::assertTrue($schema->hasTable($tableName));
     }
@@ -100,7 +97,6 @@ class SchemaTest extends TestCase
 
         $table = $schema->createTable('foo');
 
-        self::assertInstanceOf(Table::class, $table);
         self::assertEquals('foo', $table->getName());
         self::assertTrue($schema->hasTable('foo'));
     }
@@ -112,10 +108,9 @@ class SchemaTest extends TestCase
         $schema = new Schema([], [$sequence]);
 
         self::assertTrue($schema->hasSequence('a_seq'));
-        self::assertInstanceOf(Sequence::class, $schema->getSequence('a_seq'));
+        self::assertSame('a_seq', $schema->getSequence('a_seq')->getName());
 
-        $sequences = $schema->getSequences();
-        self::assertArrayHasKey('public.a_seq', $sequences);
+        self::assertEquals([$sequence], $schema->getSequences());
     }
 
     public function testSequenceAccessCaseInsensitive(): void
@@ -150,10 +145,9 @@ class SchemaTest extends TestCase
         self::assertEquals(20, $sequence->getInitialValue());
 
         self::assertTrue($schema->hasSequence('a_seq'));
-        self::assertInstanceOf(Sequence::class, $schema->getSequence('a_seq'));
+        self::assertSame('a_seq', $schema->getSequence('a_seq')->getName());
 
-        $sequences = $schema->getSequences();
-        self::assertArrayHasKey('public.a_seq', $sequences);
+        self::assertEquals([$sequence], $schema->getSequences());
     }
 
     public function testDropSequence(): void
@@ -185,7 +179,11 @@ class SchemaTest extends TestCase
         $table->addColumn('long_id', Types::INTEGER);
         $table->addIndex(['long_id']);
 
-        $index = current($table->getIndexes());
+        $indexes = $table->getIndexes();
+        self::assertCount(1, $indexes);
+
+        $index = array_shift($indexes);
+        self::assertNotNull($index);
         self::assertEquals(5, strlen($index->getName()));
     }
 
@@ -200,7 +198,7 @@ class SchemaTest extends TestCase
         $tableB = $schema->createTable('bar');
         $tableB->addColumn('id', Types::INTEGER);
         $tableB->addColumn('foo_id', Types::INTEGER);
-        $tableB->addForeignKeyConstraint($tableA, ['foo_id'], ['id']);
+        $tableB->addForeignKeyConstraint($tableA->getName(), ['foo_id'], ['id']);
 
         $schemaNew = clone $schema;
 
@@ -211,14 +209,6 @@ class SchemaTest extends TestCase
 
         self::assertNotSame($tableB, $schemaNew->getTable('bar'));
         self::assertNotSame($tableB->getColumn('id'), $schemaNew->getTable('bar')->getColumn('id'));
-
-        $fk = $schemaNew->getTable('bar')->getForeignKeys();
-        $fk = current($fk);
-
-        $re = new ReflectionProperty($fk, '_localTable');
-        $re->setAccessible(true);
-
-        self::assertSame($schemaNew->getTable('bar'), $re->getValue($fk));
     }
 
     public function testHasTableForQuotedAsset(): void
@@ -272,7 +262,7 @@ class SchemaTest extends TestCase
         self::assertTrue($schema->hasNamespace('`bar`'));
         self::assertTrue($schema->hasNamespace('`BAR`'));
 
-        self::assertSame(['foo' => 'foo', 'bar' => '`bar`'], $schema->getNamespaces());
+        self::assertSame(['foo', '`bar`'], $schema->getNamespaces());
     }
 
     public function testThrowsExceptionOnCreatingNamespaceTwice(): void
@@ -339,78 +329,4 @@ class SchemaTest extends TestCase
         self::assertTrue($schema->hasNamespace('baz'));
         self::assertFalse($schema->hasNamespace('moo'));
     }
-
-    public function testVisitsVisitor(): void
-    {
-        $schema  = new Schema();
-        $visitor = $this->createMock(Visitor::class);
-
-        $schema->createNamespace('foo');
-        $schema->createNamespace('bar');
-
-        $schema->createTable('baz');
-        $schema->createTable('bla.bloo');
-
-        $schema->createSequence('moo');
-        $schema->createSequence('war');
-
-        $visitor->expects(self::once())
-            ->method('acceptSchema')
-            ->with($schema);
-
-        $visitor->expects(self::exactly(2))
-            ->method('acceptTable')
-            ->withConsecutive(
-                [$schema->getTable('baz')],
-                [$schema->getTable('bla.bloo')],
-            );
-
-        $visitor->expects(self::exactly(2))
-            ->method('acceptSequence')
-            ->withConsecutive(
-                [$schema->getSequence('moo')],
-                [$schema->getSequence('war')],
-            );
-
-        $schema->visit($visitor);
-    }
-
-    public function testVisitsNamespaceVisitor(): void
-    {
-        $schema  = new Schema();
-        $visitor = $this->createMock(AbstractVisitor::class);
-
-        $schema->createNamespace('foo');
-        $schema->createNamespace('bar');
-
-        $schema->createTable('baz');
-        $schema->createTable('bla.bloo');
-
-        $schema->createSequence('moo');
-        $schema->createSequence('war');
-
-        $visitor->expects(self::once())
-            ->method('acceptSchema')
-            ->with($schema);
-
-        $visitor->expects($this->exactly(3))
-            ->method('acceptNamespace')
-            ->withConsecutive(['foo'], ['bar'], ['bla']);
-
-        $visitor->expects($this->exactly(2))
-            ->method('acceptTable')
-            ->withConsecutive(
-                [$schema->getTable('baz')],
-                [$schema->getTable('bla.bloo')],
-            );
-
-        $visitor->expects($this->exactly(2))
-            ->method('acceptSequence')
-            ->withConsecutive(
-                [$schema->getSequence('moo')],
-                [$schema->getSequence('war')],
-            );
-
-        $schema->visit($visitor);
-    }
 }
