@@ -1,21 +1,26 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Schema;
 
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\SchemaException;
 use Doctrine\DBAL\Schema\Table;
+use Doctrine\DBAL\Schema\UniqueConstraint;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use LogicException;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
+use function array_keys;
 use function array_shift;
-use function current;
 
 class TableTest extends TestCase
 {
@@ -44,12 +49,58 @@ class TableTest extends TestCase
         self::assertTrue($table->hasColumn('bar'));
         self::assertFalse($table->hasColumn('baz'));
 
-        self::assertInstanceOf(Column::class, $table->getColumn('foo'));
-        self::assertInstanceOf(Column::class, $table->getColumn('bar'));
+        self::assertSame('foo', $table->getColumn('foo')->getName());
+        self::assertSame('bar', $table->getColumn('bar')->getName());
 
         self::assertCount(2, $table->getColumns());
     }
 
+    public function testRenameColumn(): void
+    {
+        $typeStr   = Type::getType(Types::STRING);
+        $typeTxt   = Type::getType(Types::TEXT);
+        $columns   = [];
+        $columns[] = new Column('foo', $typeStr);
+        $table     = new Table('foo', $columns, [], []);
+
+        self::assertFalse($table->hasColumn('bar'));
+        self::assertTrue($table->hasColumn('foo'));
+
+        $column = $table->renameColumn('foo', 'bar');
+        $column->setType($typeTxt);
+        self::assertTrue($table->hasColumn('bar'), 'Should now have bar column');
+        self::assertFalse($table->hasColumn('foo'), 'Should not have foo column anymore');
+        self::assertCount(1, $table->getColumns());
+
+        self::assertEquals(['bar' => 'foo'], $table->getRenamedColumns());
+        $table->renameColumn('bar', 'baz');
+
+        self::assertTrue($table->hasColumn('baz'), 'Should now have baz column');
+        self::assertFalse($table->hasColumn('bar'), 'Should not have bar column anymore');
+        self::assertEquals(['baz' => 'foo'], $table->getRenamedColumns());
+        self::assertCount(1, $table->getColumns());
+    }
+
+    public function testRenameColumnException(): void
+    {
+        $this->expectException(LogicException::class);
+        $this->expectExceptionMessage('Attempt to rename column "foo.baz" to the same name.');
+
+        $table = new Table('foo');
+        $table->renameColumn('baz', '`BaZ`');
+    }
+
+    public function testRenameColumnLoop(): void
+    {
+        $table = new Table('foo');
+        $table->addColumn('baz', Types::INTEGER);
+        $table->renameColumn('baz', '`foo`');
+        self::assertCount(1, $table->getRenamedColumns());
+        $table->renameColumn('foo', 'Baz');
+        self::assertCount(1, $table->getColumns());
+        self::assertCount(0, $table->getRenamedColumns());
+    }
+
     public function testColumnsCaseInsensitive(): void
     {
         $table  = new Table('foo');
@@ -159,9 +210,9 @@ class TableTest extends TestCase
         self::assertTrue($table->hasIndex('bar_idx'));
         self::assertFalse($table->hasIndex('some_idx'));
 
-        self::assertInstanceOf(Index::class, $table->getPrimaryKey());
-        self::assertInstanceOf(Index::class, $table->getIndex('the_primary'));
-        self::assertInstanceOf(Index::class, $table->getIndex('bar_idx'));
+        self::assertNotNull($table->getPrimaryKey());
+        self::assertSame('the_primary', $table->getIndex('the_primary')->getName());
+        self::assertSame('bar_idx', $table->getIndex('bar_idx')->getName());
     }
 
     public function testGetUnknownIndexThrowsException(): void
@@ -206,7 +257,11 @@ class TableTest extends TestCase
         $constraints = $tableA->getForeignKeys();
 
         self::assertCount(1, $constraints);
-        self::assertSame($constraint, array_shift($constraints));
+
+        $constraintNames = array_keys($constraints);
+
+        self::assertSame('fk_8c736521', $constraintNames[0]);
+        self::assertSame($constraint, $constraints['fk_8c736521']);
     }
 
     public function testOptions(): void
@@ -289,20 +344,7 @@ class TableTest extends TestCase
         $foreignTable = new Table('bar');
         $foreignTable->addColumn('id', Types::INTEGER);
 
-        $table->addForeignKeyConstraint($foreignTable, ['foo'], ['id']);
-    }
-
-    public function testAddForeignKeyConstraintUnknownForeignColumnThrowsException(): void
-    {
-        $this->expectException(SchemaException::class);
-
-        $table = new Table('foo');
-        $table->addColumn('id', Types::INTEGER);
-
-        $foreignTable = new Table('bar');
-        $foreignTable->addColumn('id', Types::INTEGER);
-
-        $table->addForeignKeyConstraint($foreignTable, ['id'], ['foo']);
+        $table->addForeignKeyConstraint($foreignTable->getName(), ['foo'], ['id']);
     }
 
     public function testAddForeignKeyConstraint(): void
@@ -313,11 +355,11 @@ class TableTest extends TestCase
         $foreignTable = new Table('bar');
         $foreignTable->addColumn('id', Types::INTEGER);
 
-        $table->addForeignKeyConstraint($foreignTable, ['id'], ['id'], ['foo' => 'bar']);
+        $table->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id'], ['foo' => 'bar']);
 
         $constraints = $table->getForeignKeys();
         self::assertCount(1, $constraints);
-        $constraint = current($constraints);
+        $constraint = array_shift($constraints);
 
         self::assertInstanceOf(ForeignKeyConstraint::class, $constraint);
 
@@ -366,11 +408,12 @@ class TableTest extends TestCase
         $foreignTable = new Table('bar');
         $foreignTable->addColumn('id', Types::INTEGER);
 
-        $table->addForeignKeyConstraint($foreignTable, ['id'], ['id'], ['foo' => 'bar']);
+        $table->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id'], ['foo' => 'bar']);
 
         $indexes = $table->getIndexes();
         self::assertCount(1, $indexes);
-        $index = current($indexes);
+        $index = array_shift($indexes);
+        self::assertNotNull($index);
 
         self::assertTrue($table->hasIndex($index->getName()));
         self::assertEquals(['id'], $index->getColumns());
@@ -385,7 +428,7 @@ class TableTest extends TestCase
         $foreignTable = new Table('bar');
         $foreignTable->addColumn('foo', Types::INTEGER);
 
-        $table->addForeignKeyConstraint($foreignTable, ['bar'], ['foo']);
+        $table->addForeignKeyConstraint($foreignTable->getName(), ['bar'], ['foo']);
 
         self::assertCount(1, $table->getIndexes());
         self::assertTrue($table->hasIndex('bar_idx'));
@@ -405,7 +448,7 @@ class TableTest extends TestCase
         $foreignTable->addColumn('foo', Types::INTEGER);
         $foreignTable->addColumn('baz', Types::STRING);
 
-        $table->addForeignKeyConstraint($foreignTable, ['bar', 'baz'], ['foo', 'baz']);
+        $table->addForeignKeyConstraint($foreignTable->getName(), ['bar', 'baz'], ['foo', 'baz']);
 
         self::assertCount(3, $table->getIndexes());
         self::assertTrue($table->hasIndex('composite_idx'));
@@ -424,7 +467,8 @@ class TableTest extends TestCase
 
         $indexes = $table->getIndexes();
         self::assertCount(1, $indexes);
-        $index = current($indexes);
+        $index = array_shift($indexes);
+        self::assertNotNull($index);
 
         $table->addUniqueIndex(['baz']);
         self::assertCount(2, $table->getIndexes());
@@ -473,7 +517,7 @@ class TableTest extends TestCase
         // Table should only contain both the primary key table index and the unique one, even though it was overruled
         self::assertCount(2, $indexes);
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
         self::assertTrue($table->hasIndex('idx_unique'));
     }
 
@@ -484,7 +528,7 @@ class TableTest extends TestCase
 
         $localTable = new Table('local');
         $localTable->addColumn('id', Types::INTEGER);
-        $localTable->addForeignKeyConstraint($foreignTable, ['id'], ['id']);
+        $localTable->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id']);
 
         self::assertCount(1, $localTable->getIndexes());
 
@@ -501,7 +545,7 @@ class TableTest extends TestCase
 
         $localTable = new Table('local');
         $localTable->addColumn('id', Types::INTEGER);
-        $localTable->addForeignKeyConstraint($foreignTable, ['id'], ['id']);
+        $localTable->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id']);
 
         self::assertCount(1, $localTable->getIndexes());
 
@@ -518,7 +562,7 @@ class TableTest extends TestCase
 
         $localTable = new Table('local');
         $localTable->addColumn('id', Types::INTEGER);
-        $localTable->addForeignKeyConstraint($foreignTable, ['id'], ['id']);
+        $localTable->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id']);
 
         self::assertCount(1, $localTable->getIndexes());
 
@@ -535,7 +579,7 @@ class TableTest extends TestCase
 
         $localTable = new Table('local');
         $localTable->addColumn('id', Types::INTEGER);
-        $localTable->addForeignKeyConstraint($foreignTable, ['id'], ['id']);
+        $localTable->addForeignKeyConstraint($foreignTable->getName(), ['id'], ['id']);
 
         self::assertCount(1, $localTable->getIndexes());
         self::assertTrue($localTable->hasIndex('IDX_8BD688E8BF396750'));
@@ -554,7 +598,7 @@ class TableTest extends TestCase
         $table = new Table('`bar`');
 
         $mysqlPlatform  = new MySQLPlatform();
-        $sqlitePlatform = new SqlitePlatform();
+        $sqlitePlatform = new SQLitePlatform();
 
         self::assertEquals('bar', $table->getName());
         self::assertEquals('`bar`', $table->getQuotedName($mysqlPlatform));
@@ -565,12 +609,12 @@ class TableTest extends TestCase
     {
         $table = new Table('test');
 
-        self::assertFalse($table->hasPrimaryKey());
+        self::assertNull($table->getPrimaryKey());
 
         $table->addColumn('foo', Types::INTEGER);
         $table->setPrimaryKey(['foo']);
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
     }
 
     public function testAddIndexWithQuotedColumns(): void
@@ -600,17 +644,6 @@ class TableTest extends TestCase
         self::assertEquals('`test`.`test`', $table->getQuotedName(new MySQLPlatform()));
     }
 
-    public function testFullQualifiedTableName(): void
-    {
-        $table = new Table('`test`.`test`');
-        self::assertEquals('test.test', $table->getFullQualifiedName('test'));
-        self::assertEquals('test.test', $table->getFullQualifiedName('other'));
-
-        $table = new Table('test');
-        self::assertEquals('test.test', $table->getFullQualifiedName('test'));
-        self::assertEquals('other.test', $table->getFullQualifiedName('other'));
-    }
-
     public function testDropIndex(): void
     {
         $table = new Table('test');
@@ -629,10 +662,10 @@ class TableTest extends TestCase
         $table->addColumn('id', Types::INTEGER);
         $table->setPrimaryKey(['id']);
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
 
         $table->dropPrimaryKey();
-        self::assertFalse($table->hasPrimaryKey());
+        self::assertNull($table->getPrimaryKey());
     }
 
     public function testRenameIndex(): void
@@ -651,7 +684,7 @@ class TableTest extends TestCase
         self::assertSame($table, $table->renameIndex('idx', 'idx_new'));
         self::assertSame($table, $table->renameIndex('uniq', 'uniq_new'));
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
         self::assertTrue($table->hasIndex('pk_new'));
         self::assertTrue($table->hasIndex('idx_new'));
         self::assertTrue($table->hasIndex('uniq_new'));
@@ -673,7 +706,7 @@ class TableTest extends TestCase
         self::assertSame($table, $table->renameIndex('idx_new', null));
         self::assertSame($table, $table->renameIndex('uniq_new', null));
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
         self::assertTrue($table->hasIndex('primary'));
         self::assertTrue($table->hasIndex('IDX_D87F7E0C8C736521'));
         self::assertTrue($table->hasIndex('UNIQ_D87F7E0C76FF8CAA78240498'));
@@ -698,7 +731,7 @@ class TableTest extends TestCase
         self::assertSame($table, $table->renameIndex('IDX_D87F7E0C8C736521', 'idx_D87F7E0C8C736521'));
         self::assertSame($table, $table->renameIndex('UNIQ_D87F7E0C76FF8CAA78240498', 'uniq_D87F7E0C76FF8CAA78240498'));
 
-        self::assertTrue($table->hasPrimaryKey());
+        self::assertNotNull($table->getPrimaryKey());
         self::assertTrue($table->hasIndex('primary'));
         self::assertTrue($table->hasIndex('IDX_D87F7E0C8C736521'));
         self::assertTrue($table->hasIndex('UNIQ_D87F7E0C76FF8CAA78240498'));
@@ -750,7 +783,7 @@ class TableTest extends TestCase
         $table->renameIndex('idx_id', 'idx_foo');
     }
 
-    /** @dataProvider getNormalizesAssetNames */
+    #[DataProvider('getNormalizesAssetNames')]
     public function testNormalizesColumnNames(string $assetName): void
     {
         $table = new Table('test');
@@ -761,18 +794,12 @@ class TableTest extends TestCase
 
         self::assertTrue($table->hasColumn($assetName));
         self::assertTrue($table->hasColumn('foo'));
-        self::assertInstanceOf(Column::class, $table->getColumn($assetName));
-        self::assertInstanceOf(Column::class, $table->getColumn('foo'));
 
         self::assertTrue($table->hasIndex($assetName));
         self::assertTrue($table->hasIndex('foo'));
-        self::assertInstanceOf(Index::class, $table->getIndex($assetName));
-        self::assertInstanceOf(Index::class, $table->getIndex('foo'));
 
         self::assertTrue($table->hasForeignKey($assetName));
         self::assertTrue($table->hasForeignKey('foo'));
-        self::assertInstanceOf(ForeignKeyConstraint::class, $table->getForeignKey($assetName));
-        self::assertInstanceOf(ForeignKeyConstraint::class, $table->getForeignKey('foo'));
 
         $table->renameIndex($assetName, $assetName);
         self::assertTrue($table->hasIndex($assetName));
@@ -829,6 +856,35 @@ class TableTest extends TestCase
         self::assertEquals('foo', $table->getComment());
     }
 
+    public function testUniqueConstraintWithEmptyName(): void
+    {
+        $columns = [
+            new Column('column1', Type::getType(Types::STRING)),
+            new Column('column2', Type::getType(Types::STRING)),
+            new Column('column3', Type::getType(Types::STRING)),
+            new Column('column4', Type::getType(Types::STRING)),
+        ];
+
+        $uniqueConstraints = [
+            new UniqueConstraint('', ['column1', 'column2']),
+            new UniqueConstraint('', ['column3', 'column4']),
+        ];
+
+        $table = new Table('test', $columns, [], $uniqueConstraints);
+
+        $constraints = $table->getUniqueConstraints();
+
+        self::assertCount(2, $constraints);
+
+        $constraintNames = array_keys($constraints);
+
+        self::assertSame('fk_d87f7e0c341ce00bad15b1b1', $constraintNames[0]);
+        self::assertSame('fk_d87f7e0cda12812744761484', $constraintNames[1]);
+
+        self::assertSame($uniqueConstraints[0], $constraints['fk_d87f7e0c341ce00bad15b1b1']);
+        self::assertSame($uniqueConstraints[1], $constraints['fk_d87f7e0cda12812744761484']);
+    }
+
     public function testRemoveUniqueConstraint(): void
     {
         $table = new Table('foo');
