@@ -1,23 +1,23 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Tools;
 
 use Doctrine\DBAL\Driver;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Tools\DsnParser;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 use function get_class;
 use function ksort;
 
-/** @psalm-import-type Params from DriverManager */
+/** @phpstan-import-type Params from DriverManager */
 final class DsnParserTest extends TestCase
 {
-    /**
-     * @psalm-param Params $expected
-     *
-     * @dataProvider databaseUrls
-     */
+    /** @phpstan-param Params $expected */
+    #[DataProvider('databaseUrls')]
     public function testDatabaseUrl(string $dsn, array $expected): void
     {
         $parser = new DsnParser(['mysql' => 'mysqli', 'sqlite' => 'sqlite3']);
@@ -31,7 +31,7 @@ final class DsnParserTest extends TestCase
         self::assertSame($expected, $actual);
     }
 
-    /** @psalm-return iterable<string, array{string, Params}> */
+    /** @phpstan-return iterable<string, array{string, Params}> */
     public static function databaseUrls(): iterable
     {
         return [
