@@ -26,8 +26,8 @@ class AsciiStringTest extends TestCase
     public function testDelegateToPlatformForSqlDeclaration(): void
     {
         $columnDefinitions = [
-            [['length' => 12, 'fixed' => true]],
-            [['length' => 14]],
+            ['length' => 12, 'fixed' => true],
+            ['length' => 14],
         ];
 
         foreach ($columnDefinitions as $column) {
