@@ -1,27 +1,23 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\ConversionException;
 use Doctrine\DBAL\Types\JsonType;
-use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
 use function base64_encode;
 use function fopen;
-use function json_encode;
-
-use const JSON_PRESERVE_ZERO_FRACTION;
-use const JSON_THROW_ON_ERROR;
 
 class JsonTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    protected AbstractPlatform $platform;
-
+    protected AbstractPlatform&MockObject $platform;
     protected JsonType $type;
 
     protected function setUp(): void
@@ -35,11 +31,6 @@ class JsonTest extends TestCase
         self::assertSame(ParameterType::STRING, $this->type->getBindingType());
     }
 
-    public function testReturnsName(): void
-    {
-        self::assertSame(Types::JSON, $this->type->getName());
-    }
-
     public function testReturnsSQLDeclaration(): void
     {
         $this->platform->expects(self::once())
@@ -61,23 +52,23 @@ class JsonTest extends TestCase
 
     public function testJsonStringConvertsToPHPValue(): void
     {
-        $value         = ['foo' => 'bar', 'bar' => 'foo'];
-        $databaseValue = json_encode($value, 0, JSON_THROW_ON_ERROR | JSON_PRESERVE_ZERO_FRACTION);
-        $phpValue      = $this->type->convertToPHPValue($databaseValue, $this->platform);
+        $value = ['foo' => 'bar', 'bar' => 'foo'];
+
+        $databaseValue = '{"foo":"bar","bar":"foo"}';
+
+        $phpValue = $this->type->convertToPHPValue($databaseValue, $this->platform);
 
         self::assertEquals($value, $phpValue);
     }
 
-    /** @dataProvider providerFailure */
+    #[DataProvider('providerFailure')]
     public function testConversionFailure(string $data): void
     {
         $this->expectException(ConversionException::class);
         $this->type->convertToPHPValue($data, $this->platform);
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function providerFailure(): iterable
     {
         return [['a'], ['{']];
@@ -85,24 +76,16 @@ class JsonTest extends TestCase
 
     public function testJsonResourceConvertsToPHPValue(): void
     {
-        $value         = ['foo' => 'bar', 'bar' => 'foo'];
-        $databaseValue = fopen(
-            'data://text/plain;base64,' . base64_encode(json_encode(
-                $value,
-                JSON_THROW_ON_ERROR | JSON_PRESERVE_ZERO_FRACTION
-            )),
-            'r'
-        );
+        $value = ['foo' => 'bar', 'bar' => 'foo'];
+
+        $json = '{"foo":"bar","bar":"foo"}';
+
+        $databaseValue = fopen('data://text/plain;base64,' . base64_encode($json), 'r');
         $phpValue      = $this->type->convertToPHPValue($databaseValue, $this->platform);
 
         self::assertSame($value, $phpValue);
     }
 
-    public function testRequiresSQLCommentHint(): void
-    {
-        self::assertTrue($this->type->requiresSQLCommentHint($this->platform));
-    }
-
     public function testPHPNullValueConvertsToJsonNull(): void
     {
         self::assertNull($this->type->convertToDatabaseValue(null, $this->platform));
@@ -131,8 +114,8 @@ class JsonTest extends TestCase
 
         $this->expectException(ConversionException::class);
         $this->expectExceptionMessage(
-            'Could not convert PHP type \'stdClass\' to \'json\', as an \'Recursion detected\' error'
-            . ' was triggered by the serialization'
+            'Could not convert PHP type "stdClass" to "json". '
+            . 'An error was triggered by the serialization: Recursion detected',
         );
         $this->type->convertToDatabaseValue($object, $this->platform);
     }
