@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
@@ -9,9 +11,7 @@ use PHPUnit\Framework\TestCase;
 
 class StringTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private StringType $type;
 
     protected function setUp(): void
@@ -20,7 +20,7 @@ class StringTest extends TestCase
         $this->type     = new StringType();
     }
 
-    public function testReturnsSqlDeclarationFromPlatformString(): void
+    public function testReturnsSQLDeclaration(): void
     {
         $this->platform->expects(self::once())
             ->method('getStringTypeDeclarationSQL')
@@ -42,7 +42,6 @@ class StringTest extends TestCase
 
     public function testSQLConversion(): void
     {
-        self::assertFalse($this->type->canRequireSQLConversion());
         self::assertEquals('t.foo', $this->type->convertToDatabaseValueSQL('t.foo', $this->platform));
         self::assertEquals('t.foo', $this->type->convertToPHPValueSQL('t.foo', $this->platform));
     }
