@@ -7,6 +7,7 @@ namespace Doctrine\DBAL\Tests\Types;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Types\BinaryType;
 use Doctrine\DBAL\Types\BlobType;
+use Doctrine\DBAL\Types\Exception\TypeNotRegistered;
 use Doctrine\DBAL\Types\StringType;
 use Doctrine\DBAL\Types\TextType;
 use Doctrine\DBAL\Types\TypeRegistry;
@@ -45,7 +46,7 @@ class TypeRegistryTest extends TestCase
     {
         self::assertSame(
             $this->registry->get(self::TEST_TYPE_NAME),
-            $this->registry->get(self::TEST_TYPE_NAME)
+            $this->registry->get(self::TEST_TYPE_NAME),
         );
     }
 
@@ -53,14 +54,14 @@ class TypeRegistryTest extends TestCase
     {
         self::assertSame(
             self::TEST_TYPE_NAME,
-            $this->registry->lookupName($this->testType)
+            $this->registry->lookupName($this->testType),
         );
         self::assertSame(
             self::OTHER_TEST_TYPE_NAME,
-            $this->registry->lookupName($this->otherTestType)
+            $this->registry->lookupName($this->otherTestType),
         );
 
-        $this->expectException(Exception::class);
+        $this->expectException(TypeNotRegistered::class);
         $this->registry->lookupName(new TextType());
     }
 
@@ -81,7 +82,7 @@ class TypeRegistryTest extends TestCase
         self::assertSame($newType, $this->registry->get('some'));
     }
 
-    public function testRegisterWithAlradyRegisteredName(): void
+    public function testRegisterWithAlreadyRegisteredName(): void
     {
         $this->registry->register('some', new TextType());
 
@@ -93,10 +94,17 @@ class TypeRegistryTest extends TestCase
     {
         $newType = new TextType();
 
-        $this->registry->register('some', $newType);
+        $this->registry->register('type1', $newType);
+        $this->expectException(Exception::class);
+        $this->registry->register('type2', $newType);
+    }
+
+    public function testConstructorWithDuplicateInstance(): void
+    {
+        $newType = new TextType();
 
         $this->expectException(Exception::class);
-        $this->registry->register('other', $newType);
+        new TypeRegistry(['a' => $newType, 'b' => $newType]);
     }
 
     public function testOverride(): void
@@ -120,6 +128,12 @@ class TypeRegistryTest extends TestCase
         self::assertSame($type, $this->registry->get('some'));
     }
 
+    public function testOverrideWithUnknownType(): void
+    {
+        $this->expectException(Exception::class);
+        $this->registry->override('unknown', new TextType());
+    }
+
     public function testOverrideWithAlreadyRegisteredInstance(): void
     {
         $newType = new TextType();
@@ -131,12 +145,6 @@ class TypeRegistryTest extends TestCase
         $this->registry->override('second', $newType);
     }
 
-    public function testOverrideWithUnknownType(): void
-    {
-        $this->expectException(Exception::class);
-        $this->registry->override('unknown', new TextType());
-    }
-
     public function testGetMap(): void
     {
         $registeredTypes = $this->registry->getMap();
