@@ -6,18 +6,19 @@ namespace Doctrine\DBAL\Tests\Types;
 
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use ReflectionClass;
 
 class TypeTest extends TestCase
 {
-    /** @dataProvider defaultTypesProvider() */
+    #[DataProvider('defaultTypesProvider')]
     public function testDefaultTypesAreRegistered(string $name): void
     {
         self::assertTrue(Type::hasType($name));
     }
 
-    /** @dataProvider defaultTypesProvider() */
+    #[DataProvider('defaultTypesProvider')]
     public function testDefaultTypesReverseLookup(string $name): void
     {
         $type = Type::getType($name);
